# -*- coding: utf-8 -*-

"""
paypalserversdk

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""
from paypalserversdk.api_helper import APIHelper


class ApplePayPaymentData(object):

    """Implementation of the 'Apple Pay Payment Data' model.

    Information about the decrypted apple pay payment data for the token like
    cryptogram, eci indicator.

    Attributes:
        cryptogram (str): Online payment cryptogram, as defined by 3D Secure.
            The pattern is defined by an external party and supports Unicode.
        eci_indicator (str): ECI indicator, as defined by 3- Secure. The
            pattern is defined by an external party and supports Unicode.
        emv_data (str): Encoded Apple Pay EMV Payment Structure used for
            payments in China. The pattern is defined by an external party and
            supports Unicode.
        pin (str): Bank Key encrypted Apple Pay PIN. The pattern is defined by
            an external party and supports Unicode.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "cryptogram": 'cryptogram',
        "eci_indicator": 'eci_indicator',
        "emv_data": 'emv_data',
        "pin": 'pin'
    }

    _optionals = [
        'cryptogram',
        'eci_indicator',
        'emv_data',
        'pin',
    ]

    def __init__(self,
                 cryptogram=APIHelper.SKIP,
                 eci_indicator=APIHelper.SKIP,
                 emv_data=APIHelper.SKIP,
                 pin=APIHelper.SKIP):
        """Constructor for the ApplePayPaymentData class"""

        # Initialize members of the class
        if cryptogram is not APIHelper.SKIP:
            self.cryptogram = cryptogram 
        if eci_indicator is not APIHelper.SKIP:
            self.eci_indicator = eci_indicator 
        if emv_data is not APIHelper.SKIP:
            self.emv_data = emv_data 
        if pin is not APIHelper.SKIP:
            self.pin = pin 

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """

        if dictionary is None:
            return None

        # Extract variables from the dictionary
        cryptogram = dictionary.get("cryptogram") if dictionary.get("cryptogram") else APIHelper.SKIP
        eci_indicator = dictionary.get("eci_indicator") if dictionary.get("eci_indicator") else APIHelper.SKIP
        emv_data = dictionary.get("emv_data") if dictionary.get("emv_data") else APIHelper.SKIP
        pin = dictionary.get("pin") if dictionary.get("pin") else APIHelper.SKIP
        # Return an object of this model
        return cls(cryptogram,
                   eci_indicator,
                   emv_data,
                   pin)



# -*- coding: utf-8 -*-

"""
paypalserversdk

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class DisputeCategory(object):

    """Implementation of the 'Dispute Category' enum.

    The condition that is covered for the transaction.

    Attributes:
        ITEM_NOT_RECEIVED: TODO: type description here.
        UNAUTHORIZED_TRANSACTION: TODO: type description here.

    """
    ITEM_NOT_RECEIVED = 'ITEM_NOT_RECEIVED'

    UNAUTHORIZED_TRANSACTION = 'UNAUTHORIZED_TRANSACTION'




# -*- coding: utf-8 -*-

"""
paypalserversdk

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class AVSCode(object):

    """Implementation of the 'AVS Code' enum.

    The address verification code for Visa, Discover, Mastercard, or American
    Express transactions.

    Attributes:
        A: TODO: type description here.
        B: TODO: type description here.
        C: TODO: type description here.
        D: TODO: type description here.
        E: TODO: type description here.
        F: TODO: type description here.
        G: TODO: type description here.
        I: TODO: type description here.
        M: TODO: type description here.
        N: TODO: type description here.
        P: TODO: type description here.
        R: TODO: type description here.
        S: TODO: type description here.
        U: TODO: type description here.
        W: TODO: type description here.
        X: TODO: type description here.
        Y: TODO: type description here.
        Z: TODO: type description here.
        NULL: TODO: type description here.
        ENUM_0: TODO: type description here.
        ENUM_1: TODO: type description here.
        ENUM_2: TODO: type description here.
        ENUM_3: TODO: type description here.
        ENUM_4: TODO: type description here.

    """
    A = 'A'

    B = 'B'

    C = 'C'

    D = 'D'

    E = 'E'

    F = 'F'

    G = 'G'

    I = 'I'

    M = 'M'

    N = 'N'

    P = 'P'

    R = 'R'

    S = 'S'

    U = 'U'

    W = 'W'

    X = 'X'

    Y = 'Y'

    Z = 'Z'

    NULL = 'Null'

    ENUM_0 = '0'

    ENUM_1 = '1'

    ENUM_2 = '2'

    ENUM_3 = '3'

    ENUM_4 = '4'




# -*- coding: utf-8 -*-

"""
paypalserversdk

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class PayPalWalletVaultStatus(object):

    """Implementation of the 'PayPal Wallet Vault Status' enum.

    The vault status.

    Attributes:
        VAULTED: TODO: type description here.
        CREATED: TODO: type description here.
        APPROVED: TODO: type description here.

    """
    VAULTED = 'VAULTED'

    CREATED = 'CREATED'

    APPROVED = 'APPROVED'




# -*- coding: utf-8 -*-

"""
paypalserversdk

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""
from paypalserversdk.api_helper import APIHelper
from paypalserversdk.models.money import Money
from paypalserversdk.models.payee_base import PayeeBase


class PlatformFee(object):

    """Implementation of the 'Platform Fee' model.

    The platform or partner fee, commission, or brokerage fee that is
    associated with the transaction. Not a separate or isolated transaction
    leg from the external perspective. The platform fee is limited in scope
    and is always associated with the original payment for the purchase unit.

    Attributes:
        amount (Money): The currency and amount for a financial transaction,
            such as a balance or payment due.
        payee (PayeeBase): The details for the merchant who receives the funds
            and fulfills the order. The merchant is also known as the payee.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "amount": 'amount',
        "payee": 'payee'
    }

    _optionals = [
        'payee',
    ]

    def __init__(self,
                 amount=None,
                 payee=APIHelper.SKIP):
        """Constructor for the PlatformFee class"""

        # Initialize members of the class
        self.amount = amount 
        if payee is not APIHelper.SKIP:
            self.payee = payee 

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """

        if dictionary is None:
            return None

        # Extract variables from the dictionary
        amount = Money.from_dictionary(dictionary.get('amount')) if dictionary.get('amount') else None
        payee = PayeeBase.from_dictionary(dictionary.get('payee')) if 'payee' in dictionary.keys() else APIHelper.SKIP
        # Return an object of this model
        return cls(amount,
                   payee)



# -*- coding: utf-8 -*-

"""
paypalserversdk

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""
from paypalserversdk.api_helper import APIHelper
from paypalserversdk.models.capture_status_details import CaptureStatusDetails
from paypalserversdk.models.link_description import LinkDescription
from paypalserversdk.models.money import Money
from paypalserversdk.models.network_transaction_reference import NetworkTransactionReference
from paypalserversdk.models.payee import Payee
from paypalserversdk.models.payment_supplementary_data import PaymentSupplementaryData
from paypalserversdk.models.processor_response import ProcessorResponse
from paypalserversdk.models.seller_protection import SellerProtection
from paypalserversdk.models.seller_receivable_breakdown import SellerReceivableBreakdown


class CapturedPayment(object):

    """Implementation of the 'Captured Payment' model.

    A captured payment.

    Attributes:
        status (CaptureStatus): The status of the captured payment.
        status_details (CaptureStatusDetails): The details of the captured
            payment status.
        id (str): The PayPal-generated ID for the captured payment.
        amount (Money): The currency and amount for a financial transaction,
            such as a balance or payment due.
        invoice_id (str): The API caller-provided external invoice number for
            this order. Appears in both the payer's transaction history and
            the emails that the payer receives.
        custom_id (str): The API caller-provided external ID. Used to
            reconcile API caller-initiated transactions with PayPal
            transactions. Appears in transaction and settlement reports.
        network_transaction_reference (NetworkTransactionReference): Reference
            values used by the card network to identify a transaction.
        seller_protection (SellerProtection): The level of protection offered
            as defined by [PayPal Seller Protection for
            Merchants](https://www.paypal.com/us/webapps/mpp/security/seller-pr
            otection).
        final_capture (bool): Indicates whether you can make additional
            captures against the authorized payment. Set to `true` if you do
            not intend to capture additional payments against the
            authorization. Set to `false` if you intend to capture additional
            payments against the authorization.
        seller_receivable_breakdown (SellerReceivableBreakdown): The detailed
            breakdown of the capture activity. This is not available for
            transactions that are in pending state.
        disbursement_mode (DisbursementMode): The funds that are held on
            behalf of the merchant.
        links (List[LinkDescription]): An array of related [HATEOAS
            links](/docs/api/reference/api-responses/#hateoas-links).
        processor_response (ProcessorResponse): The processor response
            information for payment requests, such as direct credit card
            transactions.
        create_time (str): The date and time, in [Internet date and time
            format](https://tools.ietf.org/html/rfc3339#section-5.6). Seconds
            are required while fractional seconds are
            optional.<blockquote><strong>Note:</strong> The regular expression
            provides guidance but does not reject all invalid
            dates.</blockquote>
        update_time (str): The date and time, in [Internet date and time
            format](https://tools.ietf.org/html/rfc3339#section-5.6). Seconds
            are required while fractional seconds are
            optional.<blockquote><strong>Note:</strong> The regular expression
            provides guidance but does not reject all invalid
            dates.</blockquote>
        supplementary_data (PaymentSupplementaryData): The supplementary
            data.
        payee (Payee): The details for the merchant who receives the funds and
            fulfills the order. The merchant is also known as the payee.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "status": 'status',
        "status_details": 'status_details',
        "id": 'id',
        "amount": 'amount',
        "invoice_id": 'invoice_id',
        "custom_id": 'custom_id',
        "network_transaction_reference": 'network_transaction_reference',
        "seller_protection": 'seller_protection',
        "final_capture": 'final_capture',
        "seller_receivable_breakdown": 'seller_receivable_breakdown',
        "disbursement_mode": 'disbursement_mode',
        "links": 'links',
        "processor_response": 'processor_response',
        "create_time": 'create_time',
        "update_time": 'update_time',
        "supplementary_data": 'supplementary_data',
        "payee": 'payee'
    }

    _optionals = [
        'status',
        'status_details',
        'id',
        'amount',
        'invoice_id',
        'custom_id',
        'network_transaction_reference',
        'seller_protection',
        'final_capture',
        'seller_receivable_breakdown',
        'disbursement_mode',
        'links',
        'processor_response',
        'create_time',
        'update_time',
        'supplementary_data',
        'payee',
    ]

    def __init__(self,
                 status=APIHelper.SKIP,
                 status_details=APIHelper.SKIP,
                 id=APIHelper.SKIP,
                 amount=APIHelper.SKIP,
                 invoice_id=APIHelper.SKIP,
                 custom_id=APIHelper.SKIP,
                 network_transaction_reference=APIHelper.SKIP,
                 seller_protection=APIHelper.SKIP,
                 final_capture=False,
                 seller_receivable_breakdown=APIHelper.SKIP,
                 disbursement_mode='INSTANT',
                 links=APIHelper.SKIP,
                 processor_response=APIHelper.SKIP,
                 create_time=APIHelper.SKIP,
                 update_time=APIHelper.SKIP,
                 supplementary_data=APIHelper.SKIP,
                 payee=APIHelper.SKIP):
        """Constructor for the CapturedPayment class"""

        # Initialize members of the class
        if status is not APIHelper.SKIP:
            self.status = status 
        if status_details is not APIHelper.SKIP:
            self.status_details = status_details 
        if id is not APIHelper.SKIP:
            self.id = id 
        if amount is not APIHelper.SKIP:
            self.amount = amount 
        if invoice_id is not APIHelper.SKIP:
            self.invoice_id = invoice_id 
        if custom_id is not APIHelper.SKIP:
            self.custom_id = custom_id 
        if network_transaction_reference is not APIHelper.SKIP:
            self.network_transaction_reference = network_transaction_reference 
        if seller_protection is not APIHelper.SKIP:
            self.seller_protection = seller_protection 
        self.final_capture = final_capture 
        if seller_receivable_breakdown is not APIHelper.SKIP:
            self.seller_receivable_breakdown = seller_receivable_breakdown 
        self.disbursement_mode = disbursement_mode 
        if links is not APIHelper.SKIP:
            self.links = links 
        if processor_response is not APIHelper.SKIP:
            self.processor_response = processor_response 
        if create_time is not APIHelper.SKIP:
            self.create_time = create_time 
        if update_time is not APIHelper.SKIP:
            self.update_time = update_time 
        if supplementary_data is not APIHelper.SKIP:
            self.supplementary_data = supplementary_data 
        if payee is not APIHelper.SKIP:
            self.payee = payee 

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """

        if dictionary is None:
            return None

        # Extract variables from the dictionary
        status = dictionary.get("status") if dictionary.get("status") else APIHelper.SKIP
        status_details = CaptureStatusDetails.from_dictionary(dictionary.get('status_details')) if 'status_details' in dictionary.keys() else APIHelper.SKIP
        id = dictionary.get("id") if dictionary.get("id") else APIHelper.SKIP
        amount = Money.from_dictionary(dictionary.get('amount')) if 'amount' in dictionary.keys() else APIHelper.SKIP
        invoice_id = dictionary.get("invoice_id") if dictionary.get("invoice_id") else APIHelper.SKIP
        custom_id = dictionary.get("custom_id") if dictionary.get("custom_id") else APIHelper.SKIP
        network_transaction_reference = NetworkTransactionReference.from_dictionary(dictionary.get('network_transaction_reference')) if 'network_transaction_reference' in dictionary.keys() else APIHelper.SKIP
        seller_protection = SellerProtection.from_dictionary(dictionary.get('seller_protection')) if 'seller_protection' in dictionary.keys() else APIHelper.SKIP
        final_capture = dictionary.get("final_capture") if dictionary.get("final_capture") else False
        seller_receivable_breakdown = SellerReceivableBreakdown.from_dictionary(dictionary.get('seller_receivable_breakdown')) if 'seller_receivable_breakdown' in dictionary.keys() else APIHelper.SKIP
        disbursement_mode = dictionary.get("disbursement_mode") if dictionary.get("disbursement_mode") else 'INSTANT'
        links = None
        if dictionary.get('links') is not None:
            links = [LinkDescription.from_dictionary(x) for x in dictionary.get('links')]
        else:
            links = APIHelper.SKIP
        processor_response = ProcessorResponse.from_dictionary(dictionary.get('processor_response')) if 'processor_response' in dictionary.keys() else APIHelper.SKIP
        create_time = dictionary.get("create_time") if dictionary.get("create_time") else APIHelper.SKIP
        update_time = dictionary.get("update_time") if dictionary.get("update_time") else APIHelper.SKIP
        supplementary_data = PaymentSupplementaryData.from_dictionary(dictionary.get('supplementary_data')) if 'supplementary_data' in dictionary.keys() else APIHelper.SKIP
        payee = Payee.from_dictionary(dictionary.get('payee')) if 'payee' in dictionary.keys() else APIHelper.SKIP
        # Return an object of this model
        return cls(status,
                   status_details,
                   id,
                   amount,
                   invoice_id,
                   custom_id,
                   network_transaction_reference,
                   seller_protection,
                   final_capture,
                   seller_receivable_breakdown,
                   disbursement_mode,
                   links,
                   processor_response,
                   create_time,
                   update_time,
                   supplementary_data,
                   payee)



# -*- coding: utf-8 -*-

"""
paypalserversdk

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""
from paypalserversdk.api_helper import APIHelper
from paypalserversdk.models.money import Money


class Level2CardProcessingData(object):

    """Implementation of the 'Level 2 Card Processing Data' model.

    The level 2 card processing data collections. If your merchant account has
    been configured for Level 2 processing this field will be passed to the
    processor on your behalf. Please contact your PayPal Technical Account
    Manager to define level 2 data for your business.

    Attributes:
        invoice_id (str): Use this field to pass a purchase identification
            value of up to 127 ASCII characters. The length of this field will
            be adjusted to meet network specifications (25chars for Visa and
            Mastercard, 17chars for Amex), and the original invoice ID will
            still be displayed in your existing reports.
        tax_total (Money): The currency and amount for a financial
            transaction, such as a balance or payment due.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "invoice_id": 'invoice_id',
        "tax_total": 'tax_total'
    }

    _optionals = [
        'invoice_id',
        'tax_total',
    ]

    def __init__(self,
                 invoice_id=APIHelper.SKIP,
                 tax_total=APIHelper.SKIP):
        """Constructor for the Level2CardProcessingData class"""

        # Initialize members of the class
        if invoice_id is not APIHelper.SKIP:
            self.invoice_id = invoice_id 
        if tax_total is not APIHelper.SKIP:
            self.tax_total = tax_total 

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """

        if dictionary is None:
            return None

        # Extract variables from the dictionary
        invoice_id = dictionary.get("invoice_id") if dictionary.get("invoice_id") else APIHelper.SKIP
        tax_total = Money.from_dictionary(dictionary.get('tax_total')) if 'tax_total' in dictionary.keys() else APIHelper.SKIP
        # Return an object of this model
        return cls(invoice_id,
                   tax_total)



# -*- coding: utf-8 -*-

"""
paypalserversdk

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""
from paypalserversdk.api_helper import APIHelper
from paypalserversdk.models.venmo_wallet_additional_attributes import VenmoWalletAdditionalAttributes
from paypalserversdk.models.venmo_wallet_experience_context import VenmoWalletExperienceContext


class VenmoWalletRequest(object):

    """Implementation of the 'Venmo Wallet Request' model.

    Information needed to pay using Venmo.

    Attributes:
        vault_id (str): The PayPal-generated ID for the vaulted payment
            source. This ID should be stored on the merchant's server so the
            saved payment source can be used for future transactions.
        email_address (str): The internationalized email
            address.<blockquote><strong>Note:</strong> Up to 64 characters are
            allowed before and 255 characters are allowed after the
            <code>@</code> sign. However, the generally accepted maximum
            length for an email address is 254 characters. The pattern
            verifies that an unquoted <code>@</code> sign
            exists.</blockquote>
        experience_context (VenmoWalletExperienceContext): Customizes the
            buyer experience during the approval process for payment with
            Venmo.<blockquote><strong>Note:</strong> Partners and Marketplaces
            might configure <code>shipping_preference</code> during partner
            account setup, which overrides the request values.</blockquote>
        attributes (VenmoWalletAdditionalAttributes): Additional attributes
            associated with the use of this Venmo Wallet.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "vault_id": 'vault_id',
        "email_address": 'email_address',
        "experience_context": 'experience_context',
        "attributes": 'attributes'
    }

    _optionals = [
        'vault_id',
        'email_address',
        'experience_context',
        'attributes',
    ]

    def __init__(self,
                 vault_id=APIHelper.SKIP,
                 email_address=APIHelper.SKIP,
                 experience_context=APIHelper.SKIP,
                 attributes=APIHelper.SKIP):
        """Constructor for the VenmoWalletRequest class"""

        # Initialize members of the class
        if vault_id is not APIHelper.SKIP:
            self.vault_id = vault_id 
        if email_address is not APIHelper.SKIP:
            self.email_address = email_address 
        if experience_context is not APIHelper.SKIP:
            self.experience_context = experience_context 
        if attributes is not APIHelper.SKIP:
            self.attributes = attributes 

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """

        if dictionary is None:
            return None

        # Extract variables from the dictionary
        vault_id = dictionary.get("vault_id") if dictionary.get("vault_id") else APIHelper.SKIP
        email_address = dictionary.get("email_address") if dictionary.get("email_address") else APIHelper.SKIP
        experience_context = VenmoWalletExperienceContext.from_dictionary(dictionary.get('experience_context')) if 'experience_context' in dictionary.keys() else APIHelper.SKIP
        attributes = VenmoWalletAdditionalAttributes.from_dictionary(dictionary.get('attributes')) if 'attributes' in dictionary.keys() else APIHelper.SKIP
        # Return an object of this model
        return cls(vault_id,
                   email_address,
                   experience_context,
                   attributes)



# -*- coding: utf-8 -*-

"""
paypalserversdk

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""
from paypalserversdk.api_helper import APIHelper


class PaymentMethodPreference(object):

    """Implementation of the 'Payment Method Preference' model.

    The customer and merchant payment preferences.

    Attributes:
        payee_preferred (PayeePaymentMethodPreference): The merchant-preferred
            payment methods.
        standard_entry_class_code (StandardEntryClassCode): NACHA (the
            regulatory body governing the ACH network) requires that API
            callers (merchants, partners) obtain the consumer’s explicit
            authorization before initiating a transaction. To stay compliant,
            you’ll need to make sure that you retain a compliant authorization
            for each transaction that you originate to the ACH Network using
            this API. ACH transactions are categorized (using SEC codes) by
            how you capture authorization from the Receiver (the person whose
            bank account is being debited or credited). PayPal supports the
            following SEC codes.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "payee_preferred": 'payee_preferred',
        "standard_entry_class_code": 'standard_entry_class_code'
    }

    _optionals = [
        'payee_preferred',
        'standard_entry_class_code',
    ]

    def __init__(self,
                 payee_preferred='UNRESTRICTED',
                 standard_entry_class_code='WEB'):
        """Constructor for the PaymentMethodPreference class"""

        # Initialize members of the class
        self.payee_preferred = payee_preferred 
        self.standard_entry_class_code = standard_entry_class_code 

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """

        if dictionary is None:
            return None

        # Extract variables from the dictionary
        payee_preferred = dictionary.get("payee_preferred") if dictionary.get("payee_preferred") else 'UNRESTRICTED'
        standard_entry_class_code = dictionary.get("standard_entry_class_code") if dictionary.get("standard_entry_class_code") else 'WEB'
        # Return an object of this model
        return cls(payee_preferred,
                   standard_entry_class_code)



# -*- coding: utf-8 -*-

"""
paypalserversdk

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""
from paypalserversdk.api_helper import APIHelper


class ExchangeRate(object):

    """Implementation of the 'Exchange Rate' model.

    The exchange rate that determines the amount to convert from one currency
    to another currency.

    Attributes:
        source_currency (str): The [three-character ISO-4217 currency
            code](/api/rest/reference/currency-codes/) that identifies the
            currency.
        target_currency (str): The [three-character ISO-4217 currency
            code](/api/rest/reference/currency-codes/) that identifies the
            currency.
        value (str): The target currency amount. Equivalent to one unit of the
            source currency. Formatted as integer or decimal value with one to
            15 digits to the right of the decimal point.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "source_currency": 'source_currency',
        "target_currency": 'target_currency',
        "value": 'value'
    }

    _optionals = [
        'source_currency',
        'target_currency',
        'value',
    ]

    def __init__(self,
                 source_currency=APIHelper.SKIP,
                 target_currency=APIHelper.SKIP,
                 value=APIHelper.SKIP):
        """Constructor for the ExchangeRate class"""

        # Initialize members of the class
        if source_currency is not APIHelper.SKIP:
            self.source_currency = source_currency 
        if target_currency is not APIHelper.SKIP:
            self.target_currency = target_currency 
        if value is not APIHelper.SKIP:
            self.value = value 

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """

        if dictionary is None:
            return None

        # Extract variables from the dictionary
        source_currency = dictionary.get("source_currency") if dictionary.get("source_currency") else APIHelper.SKIP
        target_currency = dictionary.get("target_currency") if dictionary.get("target_currency") else APIHelper.SKIP
        value = dictionary.get("value") if dictionary.get("value") else APIHelper.SKIP
        # Return an object of this model
        return cls(source_currency,
                   target_currency,
                   value)



# -*- coding: utf-8 -*-

"""
paypalserversdk

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""
from paypalserversdk.models.money import Money


class RefundPlatformFee(object):

    """Implementation of the 'Refund Platform Fee' model.

    The platform or partner fee, commission, or brokerage fee that is
    associated with the transaction. Not a separate or isolated transaction
    leg from the external perspective. The platform fee is limited in scope
    and is always associated with the original payment for the purchase unit.

    Attributes:
        amount (Money): The currency and amount for a financial transaction,
            such as a balance or payment due.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "amount": 'amount'
    }

    def __init__(self,
                 amount=None):
        """Constructor for the RefundPlatformFee class"""

        # Initialize members of the class
        self.amount = amount 

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """

        if dictionary is None:
            return None

        # Extract variables from the dictionary
        amount = Money.from_dictionary(dictionary.get('amount')) if dictionary.get('amount') else None
        # Return an object of this model
        return cls(amount)



# -*- coding: utf-8 -*-

"""
paypalserversdk

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""
from paypalserversdk.api_helper import APIHelper


class TrustlyPaymentObject(object):

    """Implementation of the 'Trustly Payment Object' model.

    Information needed to pay using Trustly.

    Attributes:
        name (str): The full name representation like Mr J Smith.
        country_code (str): The [two-character ISO 3166-1
            code](/api/rest/reference/country-codes/) that identifies the
            country or region.<blockquote><strong>Note:</strong> The country
            code for Great Britain is <code>GB</code> and not <code>UK</code>
            as used in the top-level domain names for that country. Use the
            `C2` country code for China worldwide for comparable uncontrolled
            price (CUP) method, bank card, and cross-border
            transactions.</blockquote>
        bic (str): The business identification code (BIC). In payments
            systems, a BIC is used to identify a specific business, most
            commonly a bank.
        iban_last_chars (str): The last characters of the IBAN used to pay.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "name": 'name',
        "country_code": 'country_code',
        "bic": 'bic',
        "iban_last_chars": 'iban_last_chars'
    }

    _optionals = [
        'name',
        'country_code',
        'bic',
        'iban_last_chars',
    ]

    def __init__(self,
                 name=APIHelper.SKIP,
                 country_code=APIHelper.SKIP,
                 bic=APIHelper.SKIP,
                 iban_last_chars=APIHelper.SKIP):
        """Constructor for the TrustlyPaymentObject class"""

        # Initialize members of the class
        if name is not APIHelper.SKIP:
            self.name = name 
        if country_code is not APIHelper.SKIP:
            self.country_code = country_code 
        if bic is not APIHelper.SKIP:
            self.bic = bic 
        if iban_last_chars is not APIHelper.SKIP:
            self.iban_last_chars = iban_last_chars 

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """

        if dictionary is None:
            return None

        # Extract variables from the dictionary
        name = dictionary.get("name") if dictionary.get("name") else APIHelper.SKIP
        country_code = dictionary.get("country_code") if dictionary.get("country_code") else APIHelper.SKIP
        bic = dictionary.get("bic") if dictionary.get("bic") else APIHelper.SKIP
        iban_last_chars = dictionary.get("iban_last_chars") if dictionary.get("iban_last_chars") else APIHelper.SKIP
        # Return an object of this model
        return cls(name,
                   country_code,
                   bic,
                   iban_last_chars)



# -*- coding: utf-8 -*-

"""
paypalserversdk

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class OrderApplicationContextUserAction(object):

    """Implementation of the 'Order Application Context User Action' enum.

    DEPRECATED. Configures a <strong>Continue</strong> or <strong>Pay
    Now</strong> checkout flow.  The fields in `application_context` are now
    available in the `experience_context` object under the `payment_source`
    which supports them (eg.
    `payment_source.paypal.experience_context.user_action`). Please specify
    this field in the `experience_context` object instead of the
    `application_context` object.

    Attributes:
        CONTINUE: TODO: type description here.
        PAY_NOW: TODO: type description here.

    """
    CONTINUE = 'CONTINUE'

    PAY_NOW = 'PAY_NOW'




# -*- coding: utf-8 -*-

"""
paypalserversdk

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""
from paypalserversdk.api_helper import APIHelper
from paypalserversdk.models.payment_token_request_card import PaymentTokenRequestCard
from paypalserversdk.models.vault_token_request import VaultTokenRequest


class PaymentTokenRequestPaymentSource(object):

    """Implementation of the 'Payment Token Request Payment Source' model.

    The payment method to vault with the instrument details.

    Attributes:
        card (PaymentTokenRequestCard): A Resource representing a request to
            vault a Card.
        token (VaultTokenRequest): The Tokenized Payment Source representing a
            Request to Vault a Token.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "card": 'card',
        "token": 'token'
    }

    _optionals = [
        'card',
        'token',
    ]

    def __init__(self,
                 card=APIHelper.SKIP,
                 token=APIHelper.SKIP):
        """Constructor for the PaymentTokenRequestPaymentSource class"""

        # Initialize members of the class
        if card is not APIHelper.SKIP:
            self.card = card 
        if token is not APIHelper.SKIP:
            self.token = token 

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """

        if dictionary is None:
            return None

        # Extract variables from the dictionary
        card = PaymentTokenRequestCard.from_dictionary(dictionary.get('card')) if 'card' in dictionary.keys() else APIHelper.SKIP
        token = VaultTokenRequest.from_dictionary(dictionary.get('token')) if 'token' in dictionary.keys() else APIHelper.SKIP
        # Return an object of this model
        return cls(card,
                   token)



# -*- coding: utf-8 -*-

"""
paypalserversdk

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class TaxIdType(object):

    """Implementation of the 'Tax Id Type' enum.

    The customer's tax ID type.

    Attributes:
        BR_CPF: TODO: type description here.
        BR_CNPJ: TODO: type description here.

    """
    BR_CPF = 'BR_CPF'

    BR_CNPJ = 'BR_CNPJ'




# -*- coding: utf-8 -*-

"""
paypalserversdk

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""
from paypalserversdk.api_helper import APIHelper


class VenmoWalletExperienceContext(object):

    """Implementation of the 'Venmo Wallet Experience Context' model.

    Customizes the buyer experience during the approval process for payment
    with Venmo.<blockquote><strong>Note:</strong> Partners and Marketplaces
    might configure <code>shipping_preference</code> during partner account
    setup, which overrides the request values.</blockquote>

    Attributes:
        brand_name (str): The business name of the merchant. The pattern is
            defined by an external party and supports Unicode.
        shipping_preference (ShippingPreference): The location from which the
            shipping address is derived.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "brand_name": 'brand_name',
        "shipping_preference": 'shipping_preference'
    }

    _optionals = [
        'brand_name',
        'shipping_preference',
    ]

    def __init__(self,
                 brand_name=APIHelper.SKIP,
                 shipping_preference='GET_FROM_FILE'):
        """Constructor for the VenmoWalletExperienceContext class"""

        # Initialize members of the class
        if brand_name is not APIHelper.SKIP:
            self.brand_name = brand_name 
        self.shipping_preference = shipping_preference 

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """

        if dictionary is None:
            return None

        # Extract variables from the dictionary
        brand_name = dictionary.get("brand_name") if dictionary.get("brand_name") else APIHelper.SKIP
        shipping_preference = dictionary.get("shipping_preference") if dictionary.get("shipping_preference") else 'GET_FROM_FILE'
        # Return an object of this model
        return cls(brand_name,
                   shipping_preference)



# -*- coding: utf-8 -*-

"""
paypalserversdk

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class ShippingPreference(object):

    """Implementation of the 'Shipping Preference' enum.

    The location from which the shipping address is derived.

    Attributes:
        GET_FROM_FILE: TODO: type description here.
        NO_SHIPPING: TODO: type description here.
        SET_PROVIDED_ADDRESS: TODO: type description here.

    """
    GET_FROM_FILE = 'GET_FROM_FILE'

    NO_SHIPPING = 'NO_SHIPPING'

    SET_PROVIDED_ADDRESS = 'SET_PROVIDED_ADDRESS'




# -*- coding: utf-8 -*-

"""
paypalserversdk

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class CheckoutPaymentIntent(object):

    """Implementation of the 'Checkout Payment Intent' enum.

    The intent to either capture payment immediately or authorize a payment
    for an order after order creation.

    Attributes:
        CAPTURE: TODO: type description here.
        AUTHORIZE: TODO: type description here.

    """
    CAPTURE = 'CAPTURE'

    AUTHORIZE = 'AUTHORIZE'




# -*- coding: utf-8 -*-

"""
paypalserversdk

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class GooglePayAuthenticationMethod(object):

    """Implementation of the 'Google Pay Authentication Method' enum.

    Authentication Method which is used for the card transaction.

    Attributes:
        PAN_ONLY: TODO: type description here.
        CRYPTOGRAM_3DS: TODO: type description here.

    """
    PAN_ONLY = 'PAN_ONLY'

    CRYPTOGRAM_3DS = 'CRYPTOGRAM_3DS'




# -*- coding: utf-8 -*-

"""
paypalserversdk

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""

from paypalserversdk.api_helper import APIHelper
from paypalserversdk.configuration import Server
from paypalserversdk.http.api_response import ApiResponse
from paypalserversdk.controllers.base_controller import BaseController
from apimatic_core.request_builder import RequestBuilder
from apimatic_core.response_handler import ResponseHandler
from apimatic_core.types.parameter import Parameter
from paypalserversdk.http.http_method_enum import HttpMethodEnum
from paypalserversdk.models.o_auth_token import OAuthToken
from paypalserversdk.exceptions.o_auth_provider_exception import OAuthProviderException


class OAuthAuthorizationController(BaseController):

    """A Controller to access Endpoints in the paypalserversdk API."""
    def __init__(self, config):
        super(OAuthAuthorizationController, self).__init__(config)

    def request_token(self,
                      options=dict(),
                      _optional_form_parameters=None):
        """Does a POST request to /v1/oauth2/token.

        Create a new OAuth 2 token.

        Args:
            options (dict, optional): Key-value pairs for any of the
                parameters to this API Endpoint. All parameters to the
                endpoint are supplied through the dictionary with their names
                being the key and their desired values being the value. A list
                of parameters that can be used are::

                    authorization -- str -- Authorization header in Basic auth
                        format
                    scope -- str -- Requested scopes as a space-delimited
                        list.

        Returns:
            ApiResponse: An object with the response value as well as other
                useful information such as status codes and headers.

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        return super().new_api_call_builder.request(
            RequestBuilder().server(Server.DEFAULT)
            .path('/v1/oauth2/token')
            .http_method(HttpMethodEnum.POST)
            .form_param(Parameter()
                        .key('grant_type')
                        .value('client_credentials'))
            .header_param(Parameter()
                          .key('Authorization')
                          .value(options.get('authorization', None)))
            .form_param(Parameter()
                        .key('scope')
                        .value(options.get('scope', None)))
            .header_param(Parameter()
                          .key('content-type')
                          .value('application/x-www-form-urlencoded'))
            .header_param(Parameter()
                          .key('accept')
                          .value('application/json'))
            .additional_form_params(_optional_form_parameters)
        ).response(
            ResponseHandler()
            .deserializer(APIHelper.json_deserialize)
            .deserialize_into(OAuthToken.from_dictionary)
            .is_api_response(True)
            .local_error('400', 'OAuth 2 provider returned an error.', OAuthProviderException)
            .local_error('401', 'OAuth 2 provider says client authentication failed.', OAuthProviderException)
        ).execute()



# -*- coding: utf-8 -*-

"""
paypalserversdk

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""
from paypalserversdk.api_helper import APIHelper
from paypalserversdk.models.card_verification import CardVerification


class GooglePayCardAttributes(object):

    """Implementation of the 'Google Pay Card Attributes' model.

    Additional attributes associated with the use of this card.

    Attributes:
        verification (CardVerification): The API caller can opt in to verify
            the card through PayPal offered verification services (e.g. Smart
            Dollar Auth, 3DS).

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "verification": 'verification'
    }

    _optionals = [
        'verification',
    ]

    def __init__(self,
                 verification=APIHelper.SKIP):
        """Constructor for the GooglePayCardAttributes class"""

        # Initialize members of the class
        if verification is not APIHelper.SKIP:
            self.verification = verification 

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """

        if dictionary is None:
            return None

        # Extract variables from the dictionary
        verification = CardVerification.from_dictionary(dictionary.get('verification')) if 'verification' in dictionary.keys() else APIHelper.SKIP
        # Return an object of this model
        return cls(verification)



# -*- coding: utf-8 -*-

"""
paypalserversdk

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""
from paypalserversdk.api_helper import APIHelper
from paypalserversdk.models.customer_request import CustomerRequest
from paypalserversdk.models.link_description import LinkDescription
from paypalserversdk.models.payment_token_response import PaymentTokenResponse


class CustomerVaultPaymentTokensResponse(object):

    """Implementation of the 'Customer Vault Payment Tokens Response' model.

    Collection of payment tokens saved for a given customer.

    Attributes:
        total_items (int): Total number of items.
        total_pages (int): Total number of pages.
        customer (CustomerRequest): Customer in merchant's or partner's system
            of records.
        payment_tokens (List[PaymentTokenResponse]): TODO: type description
            here.
        links (List[LinkDescription]): An array of related [HATEOAS
            links](/api/rest/responses/#hateoas).

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "total_items": 'total_items',
        "total_pages": 'total_pages',
        "customer": 'customer',
        "payment_tokens": 'payment_tokens',
        "links": 'links'
    }

    _optionals = [
        'total_items',
        'total_pages',
        'customer',
        'payment_tokens',
        'links',
    ]

    def __init__(self,
                 total_items=APIHelper.SKIP,
                 total_pages=APIHelper.SKIP,
                 customer=APIHelper.SKIP,
                 payment_tokens=APIHelper.SKIP,
                 links=APIHelper.SKIP):
        """Constructor for the CustomerVaultPaymentTokensResponse class"""

        # Initialize members of the class
        if total_items is not APIHelper.SKIP:
            self.total_items = total_items 
        if total_pages is not APIHelper.SKIP:
            self.total_pages = total_pages 
        if customer is not APIHelper.SKIP:
            self.customer = customer 
        if payment_tokens is not APIHelper.SKIP:
            self.payment_tokens = payment_tokens 
        if links is not APIHelper.SKIP:
            self.links = links 

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """

        if dictionary is None:
            return None

        # Extract variables from the dictionary
        total_items = dictionary.get("total_items") if dictionary.get("total_items") else APIHelper.SKIP
        total_pages = dictionary.get("total_pages") if dictionary.get("total_pages") else APIHelper.SKIP
        customer = CustomerRequest.from_dictionary(dictionary.get('customer')) if 'customer' in dictionary.keys() else APIHelper.SKIP
        payment_tokens = None
        if dictionary.get('payment_tokens') is not None:
            payment_tokens = [PaymentTokenResponse.from_dictionary(x) for x in dictionary.get('payment_tokens')]
        else:
            payment_tokens = APIHelper.SKIP
        links = None
        if dictionary.get('links') is not None:
            links = [LinkDescription.from_dictionary(x) for x in dictionary.get('links')]
        else:
            links = APIHelper.SKIP
        # Return an object of this model
        return cls(total_items,
                   total_pages,
                   customer,
                   payment_tokens,
                   links)



# -*- coding: utf-8 -*-

"""
paypalserversdk

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""
from paypalserversdk.api_helper import APIHelper
from paypalserversdk.models.phone_number import PhoneNumber


class PhoneWithType(object):

    """Implementation of the 'Phone With Type' model.

    The phone information.

    Attributes:
        phone_type (PhoneType): The phone type.
        phone_number (PhoneNumber): The phone number in its canonical
            international [E.164 numbering plan
            format](https://www.itu.int/rec/T-REC-E.164/en).

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "phone_number": 'phone_number',
        "phone_type": 'phone_type'
    }

    _optionals = [
        'phone_type',
    ]

    def __init__(self,
                 phone_number=None,
                 phone_type=APIHelper.SKIP):
        """Constructor for the PhoneWithType class"""

        # Initialize members of the class
        if phone_type is not APIHelper.SKIP:
            self.phone_type = phone_type 
        self.phone_number = phone_number 

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """

        if dictionary is None:
            return None

        # Extract variables from the dictionary
        phone_number = PhoneNumber.from_dictionary(dictionary.get('phone_number')) if dictionary.get('phone_number') else None
        phone_type = dictionary.get("phone_type") if dictionary.get("phone_type") else APIHelper.SKIP
        # Return an object of this model
        return cls(phone_number,
                   phone_type)



# -*- coding: utf-8 -*-

"""
paypalserversdk

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""

from abc import abstractmethod

from apimatic_core_interfaces.logger.logger import Logger


class AbstractLogger(Logger):

    @abstractmethod
    def log(self, level, message, params):
        """Logs a message with a specified log level and additional parameters.

        Args:
            level (int): The log level of the message.
            message (str): The message to log.
            params (dict): Additional parameters to include in the log message.
        """
        ...



# -*- coding: utf-8 -*-

"""
paypalserversdk

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""
from paypalserversdk.api_helper import APIHelper


class BLIKOneClickPaymentObject(object):

    """Implementation of the 'BLIK One-Click Payment Object' model.

    Information used to pay using BLIK one-click flow.

    Attributes:
        consumer_reference (str): The merchant generated, unique reference
            serving as a primary identifier for accounts connected between
            Blik and a merchant.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "consumer_reference": 'consumer_reference'
    }

    _optionals = [
        'consumer_reference',
    ]

    def __init__(self,
                 consumer_reference=APIHelper.SKIP):
        """Constructor for the BLIKOneClickPaymentObject class"""

        # Initialize members of the class
        if consumer_reference is not APIHelper.SKIP:
            self.consumer_reference = consumer_reference 

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """

        if dictionary is None:
            return None

        # Extract variables from the dictionary
        consumer_reference = dictionary.get("consumer_reference") if dictionary.get("consumer_reference") else APIHelper.SKIP
        # Return an object of this model
        return cls(consumer_reference)



# -*- coding: utf-8 -*-

"""
paypalserversdk

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""
from paypalserversdk.api_helper import APIHelper
from paypalserversdk.models.name import Name
from paypalserversdk.models.phone import Phone


class AddressDetails(object):

    """Implementation of the 'Address Details' model.

    Address request details.

    Attributes:
        address_line_1 (str): The first line of the address, such as number
            and street, for example, `173 Drury Lane`. Needed for data entry,
            and Compliance and Risk checks. This field needs to pass the full
            address.
        address_line_2 (str): The second line of the address, for example, a
            suite or apartment number.
        admin_area_2 (str): A city, town, or village. Smaller than
            `admin_area_level_1`.
        admin_area_1 (str): The highest-level sub-division in a country, which
            is usually a province, state, or ISO-3166-2 subdivision. This data
            is formatted for postal delivery, for example, `CA` and not
            `California`. Value, by country, is:<ul><li>UK. A
            county.</li><li>US. A state.</li><li>Canada. A
            province.</li><li>Japan. A prefecture.</li><li>Switzerland. A
            *kanton*.</li></ul>
        postal_code (str): The postal code, which is the ZIP code or
            equivalent. Typically required for countries with a postal code or
            an equivalent. See [postal
            code](https://en.wikipedia.org/wiki/Postal_code).
        country_code (str): The [2-character ISO 3166-1
            code](/api/rest/reference/country-codes/) that identifies the
            country or region.<blockquote><strong>Note:</strong> The country
            code for Great Britain is <code>GB</code> and not <code>UK</code>
            as used in the top-level domain names for that country. Use the
            `C2` country code for China worldwide for comparable uncontrolled
            price (CUP) method, bank card, and cross-border
            transactions.</blockquote>
        name (Name): The name of the party.
        id (str): The resource ID of the address.
        company (str): The name of the company or business associated to the
            address.
        phone (str): The phone number that can go on the mailing label with
            the address to track the shipping. Phone number is in E.164
            format.
        phone_number (Phone): The phone number, in its canonical international
            [E.164 numbering plan
            format](https://www.itu.int/rec/T-REC-E.164/en).

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "country_code": 'country_code',
        "address_line_1": 'address_line_1',
        "address_line_2": 'address_line_2',
        "admin_area_2": 'admin_area_2',
        "admin_area_1": 'admin_area_1',
        "postal_code": 'postal_code',
        "name": 'name',
        "id": 'id',
        "company": 'company',
        "phone": 'phone',
        "phone_number": 'phone_number'
    }

    _optionals = [
        'address_line_1',
        'address_line_2',
        'admin_area_2',
        'admin_area_1',
        'postal_code',
        'name',
        'id',
        'company',
        'phone',
        'phone_number',
    ]

    def __init__(self,
                 country_code=None,
                 address_line_1=APIHelper.SKIP,
                 address_line_2=APIHelper.SKIP,
                 admin_area_2=APIHelper.SKIP,
                 admin_area_1=APIHelper.SKIP,
                 postal_code=APIHelper.SKIP,
                 name=APIHelper.SKIP,
                 id=APIHelper.SKIP,
                 company=APIHelper.SKIP,
                 phone=APIHelper.SKIP,
                 phone_number=APIHelper.SKIP):
        """Constructor for the AddressDetails class"""

        # Initialize members of the class
        if address_line_1 is not APIHelper.SKIP:
            self.address_line_1 = address_line_1 
        if address_line_2 is not APIHelper.SKIP:
            self.address_line_2 = address_line_2 
        if admin_area_2 is not APIHelper.SKIP:
            self.admin_area_2 = admin_area_2 
        if admin_area_1 is not APIHelper.SKIP:
            self.admin_area_1 = admin_area_1 
        if postal_code is not APIHelper.SKIP:
            self.postal_code = postal_code 
        self.country_code = country_code 
        if name is not APIHelper.SKIP:
            self.name = name 
        if id is not APIHelper.SKIP:
            self.id = id 
        if company is not APIHelper.SKIP:
            self.company = company 
        if phone is not APIHelper.SKIP:
            self.phone = phone 
        if phone_number is not APIHelper.SKIP:
            self.phone_number = phone_number 

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """

        if dictionary is None:
            return None

        # Extract variables from the dictionary
        country_code = dictionary.get("country_code") if dictionary.get("country_code") else None
        address_line_1 = dictionary.get("address_line_1") if dictionary.get("address_line_1") else APIHelper.SKIP
        address_line_2 = dictionary.get("address_line_2") if dictionary.get("address_line_2") else APIHelper.SKIP
        admin_area_2 = dictionary.get("admin_area_2") if dictionary.get("admin_area_2") else APIHelper.SKIP
        admin_area_1 = dictionary.get("admin_area_1") if dictionary.get("admin_area_1") else APIHelper.SKIP
        postal_code = dictionary.get("postal_code") if dictionary.get("postal_code") else APIHelper.SKIP
        name = Name.from_dictionary(dictionary.get('name')) if 'name' in dictionary.keys() else APIHelper.SKIP
        id = dictionary.get("id") if dictionary.get("id") else APIHelper.SKIP
        company = dictionary.get("company") if dictionary.get("company") else APIHelper.SKIP
        phone = dictionary.get("phone") if dictionary.get("phone") else APIHelper.SKIP
        phone_number = Phone.from_dictionary(dictionary.get('phone_number')) if 'phone_number' in dictionary.keys() else APIHelper.SKIP
        # Return an object of this model
        return cls(country_code,
                   address_line_1,
                   address_line_2,
                   admin_area_2,
                   admin_area_1,
                   postal_code,
                   name,
                   id,
                   company,
                   phone,
                   phone_number)



# -*- coding: utf-8 -*-

"""
paypalserversdk

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""
from paypalserversdk.api_helper import APIHelper
from paypalserversdk.models.money import Money
from paypalserversdk.models.universal_product_code import UniversalProductCode


class Item(object):

    """Implementation of the 'Item' model.

    The details for the items to be purchased.

    Attributes:
        name (str): The item name or title.
        unit_amount (Money): The currency and amount for a financial
            transaction, such as a balance or payment due.
        tax (Money): The currency and amount for a financial transaction, such
            as a balance or payment due.
        quantity (str): The item quantity. Must be a whole number.
        description (str): The detailed item description.
        sku (str): The stock keeping unit (SKU) for the item.
        url (str): The URL to the item being purchased. Visible to buyer and
            used in buyer experiences.
        category (ItemCategory): The item category type.
        image_url (str): The URL of the item's image. File type and size
            restrictions apply. An image that violates these restrictions will
            not be honored.
        upc (UniversalProductCode): The Universal Product Code of the item.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "name": 'name',
        "unit_amount": 'unit_amount',
        "quantity": 'quantity',
        "tax": 'tax',
        "description": 'description',
        "sku": 'sku',
        "url": 'url',
        "category": 'category',
        "image_url": 'image_url',
        "upc": 'upc'
    }

    _optionals = [
        'tax',
        'description',
        'sku',
        'url',
        'category',
        'image_url',
        'upc',
    ]

    def __init__(self,
                 name=None,
                 unit_amount=None,
                 quantity=None,
                 tax=APIHelper.SKIP,
                 description=APIHelper.SKIP,
                 sku=APIHelper.SKIP,
                 url=APIHelper.SKIP,
                 category=APIHelper.SKIP,
                 image_url=APIHelper.SKIP,
                 upc=APIHelper.SKIP):
        """Constructor for the Item class"""

        # Initialize members of the class
        self.name = name 
        self.unit_amount = unit_amount 
        if tax is not APIHelper.SKIP:
            self.tax = tax 
        self.quantity = quantity 
        if description is not APIHelper.SKIP:
            self.description = description 
        if sku is not APIHelper.SKIP:
            self.sku = sku 
        if url is not APIHelper.SKIP:
            self.url = url 
        if category is not APIHelper.SKIP:
            self.category = category 
        if image_url is not APIHelper.SKIP:
            self.image_url = image_url 
        if upc is not APIHelper.SKIP:
            self.upc = upc 

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """

        if dictionary is None:
            return None

        # Extract variables from the dictionary
        name = dictionary.get("name") if dictionary.get("name") else None
        unit_amount = Money.from_dictionary(dictionary.get('unit_amount')) if dictionary.get('unit_amount') else None
        quantity = dictionary.get("quantity") if dictionary.get("quantity") else None
        tax = Money.from_dictionary(dictionary.get('tax')) if 'tax' in dictionary.keys() else APIHelper.SKIP
        description = dictionary.get("description") if dictionary.get("description") else APIHelper.SKIP
        sku = dictionary.get("sku") if dictionary.get("sku") else APIHelper.SKIP
        url = dictionary.get("url") if dictionary.get("url") else APIHelper.SKIP
        category = dictionary.get("category") if dictionary.get("category") else APIHelper.SKIP
        image_url = dictionary.get("image_url") if dictionary.get("image_url") else APIHelper.SKIP
        upc = UniversalProductCode.from_dictionary(dictionary.get('upc')) if 'upc' in dictionary.keys() else APIHelper.SKIP
        # Return an object of this model
        return cls(name,
                   unit_amount,
                   quantity,
                   tax,
                   description,
                   sku,
                   url,
                   category,
                   image_url,
                   upc)



# -*- coding: utf-8 -*-

"""
paypalserversdk

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""
from paypalserversdk.api_helper import APIHelper


class LinkDescription(object):

    """Implementation of the 'Link Description' model.

    The request-related [HATEOAS link](/api/rest/responses/#hateoas-links)
    information.

    Attributes:
        href (str): The complete target URL. To make the related call, combine
            the method with this [URI
            Template-formatted](https://tools.ietf.org/html/rfc6570) link. For
            pre-processing, include the `$`, `(`, and `)` characters. The
            `href` is the key HATEOAS component that links a completed call
            with a subsequent call.
        rel (str): The [link relation
            type](https://tools.ietf.org/html/rfc5988#section-4), which serves
            as an ID for a link that unambiguously describes the semantics of
            the link. See [Link
            Relations](https://www.iana.org/assignments/link-relations/link-rel
            ations.xhtml).
        method (LinkHTTPMethod): The HTTP method required to make the related
            call.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "href": 'href',
        "rel": 'rel',
        "method": 'method'
    }

    _optionals = [
        'method',
    ]

    def __init__(self,
                 href=None,
                 rel=None,
                 method=APIHelper.SKIP):
        """Constructor for the LinkDescription class"""

        # Initialize members of the class
        self.href = href 
        self.rel = rel 
        if method is not APIHelper.SKIP:
            self.method = method 

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """

        if dictionary is None:
            return None

        # Extract variables from the dictionary
        href = dictionary.get("href") if dictionary.get("href") else None
        rel = dictionary.get("rel") if dictionary.get("rel") else None
        method = dictionary.get("method") if dictionary.get("method") else APIHelper.SKIP
        # Return an object of this model
        return cls(href,
                   rel,
                   method)



# -*- coding: utf-8 -*-

"""
paypalserversdk

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""
from paypalserversdk.api_helper import APIHelper
from paypalserversdk.models.order_capture_request_payment_source import OrderCaptureRequestPaymentSource


class OrderCaptureRequest(object):

    """Implementation of the 'Order Capture Request' model.

    Completes an capture payment for an order.

    Attributes:
        payment_source (OrderCaptureRequestPaymentSource): The payment source
            definition.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "payment_source": 'payment_source'
    }

    _optionals = [
        'payment_source',
    ]

    def __init__(self,
                 payment_source=APIHelper.SKIP):
        """Constructor for the OrderCaptureRequest class"""

        # Initialize members of the class
        if payment_source is not APIHelper.SKIP:
            self.payment_source = payment_source 

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """

        if dictionary is None:
            return None

        # Extract variables from the dictionary
        payment_source = OrderCaptureRequestPaymentSource.from_dictionary(dictionary.get('payment_source')) if 'payment_source' in dictionary.keys() else APIHelper.SKIP
        # Return an object of this model
        return cls(payment_source)



# -*- coding: utf-8 -*-

"""
paypalserversdk

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class VaultTokenRequest(object):

    """Implementation of the 'Vault Token Request' model.

    The Tokenized Payment Source representing a Request to Vault a Token.

    Attributes:
        id (str): The PayPal-generated ID for the token.
        mtype (TokenRequestType): The tokenization method that generated the
            ID.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "id": 'id',
        "mtype": 'type'
    }

    def __init__(self,
                 id=None,
                 mtype=None):
        """Constructor for the VaultTokenRequest class"""

        # Initialize members of the class
        self.id = id 
        self.mtype = mtype 

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """

        if dictionary is None:
            return None

        # Extract variables from the dictionary
        id = dictionary.get("id") if dictionary.get("id") else None
        mtype = dictionary.get("type") if dictionary.get("type") else None
        # Return an object of this model
        return cls(id,
                   mtype)



# -*- coding: utf-8 -*-

"""
paypalserversdk

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""
from paypalserversdk.api_helper import APIHelper


class SellerProtection(object):

    """Implementation of the 'Seller Protection' model.

    The level of protection offered as defined by [PayPal Seller Protection
    for
    Merchants](https://www.paypal.com/us/webapps/mpp/security/seller-protection
    ).

    Attributes:
        status (SellerProtectionStatus): Indicates whether the transaction is
            eligible for seller protection. For information, see [PayPal
            Seller Protection for
            Merchants](https://www.paypal.com/us/webapps/mpp/security/seller-pr
            otection).
        dispute_categories (List[DisputeCategory]): An array of conditions
            that are covered for the transaction.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "status": 'status',
        "dispute_categories": 'dispute_categories'
    }

    _optionals = [
        'status',
        'dispute_categories',
    ]

    def __init__(self,
                 status=APIHelper.SKIP,
                 dispute_categories=APIHelper.SKIP):
        """Constructor for the SellerProtection class"""

        # Initialize members of the class
        if status is not APIHelper.SKIP:
            self.status = status 
        if dispute_categories is not APIHelper.SKIP:
            self.dispute_categories = dispute_categories 

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """

        if dictionary is None:
            return None

        # Extract variables from the dictionary
        status = dictionary.get("status") if dictionary.get("status") else APIHelper.SKIP
        dispute_categories = dictionary.get("dispute_categories") if dictionary.get("dispute_categories") else APIHelper.SKIP
        # Return an object of this model
        return cls(status,
                   dispute_categories)



# -*- coding: utf-8 -*-

"""
paypalserversdk

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class PhoneNumber(object):

    """Implementation of the 'Phone Number' model.

    The phone number in its canonical international [E.164 numbering plan
    format](https://www.itu.int/rec/T-REC-E.164/en).

    Attributes:
        national_number (str): The national number, in its canonical
            international [E.164 numbering plan
            format](https://www.itu.int/rec/T-REC-E.164/en). The combined
            length of the country calling code (CC) and the national number
            must not be greater than 15 digits. The national number consists
            of a national destination code (NDC) and subscriber number (SN).

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "national_number": 'national_number'
    }

    def __init__(self,
                 national_number=None):
        """Constructor for the PhoneNumber class"""

        # Initialize members of the class
        self.national_number = national_number 

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """

        if dictionary is None:
            return None

        # Extract variables from the dictionary
        national_number = dictionary.get("national_number") if dictionary.get("national_number") else None
        # Return an object of this model
        return cls(national_number)



# -*- coding: utf-8 -*-

"""
paypalserversdk

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class ShippingType(object):

    """Implementation of the 'Shipping Type' enum.

    A classification for the method of purchase fulfillment.

    Attributes:
        SHIPPING: TODO: type description here.
        PICKUP: TODO: type description here.
        PICKUP_IN_STORE: TODO: type description here.
        PICKUP_FROM_PERSON: TODO: type description here.

    """
    SHIPPING = 'SHIPPING'

    PICKUP = 'PICKUP'

    PICKUP_IN_STORE = 'PICKUP_IN_STORE'

    PICKUP_FROM_PERSON = 'PICKUP_FROM_PERSON'




# -*- coding: utf-8 -*-

"""
paypalserversdk

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class LiabilityShiftIndicator(object):

    """Implementation of the 'Liability Shift Indicator' enum.

    Liability shift indicator. The outcome of the issuer's authentication.

    Attributes:
        NO: TODO: type description here.
        POSSIBLE: TODO: type description here.
        UNKNOWN: TODO: type description here.

    """
    NO = 'NO'

    POSSIBLE = 'POSSIBLE'

    UNKNOWN = 'UNKNOWN'




# -*- coding: utf-8 -*-

"""
paypalserversdk

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""
from paypalserversdk.api_helper import APIHelper
from paypalserversdk.models.address import Address


class ApplePayCard(object):

    """Implementation of the 'Apple Pay Card' model.

    The payment card to be used to fund a payment. Can be a credit or debit
    card.

    Attributes:
        name (str): The card holder's name as it appears on the card.
        last_digits (str): The last digits of the payment card.
        mtype (CardType): Type of card. i.e Credit, Debit and so on.
        brand (CardBrand): The card network or brand. Applies to credit,
            debit, gift, and payment cards.
        billing_address (Address): The portable international postal address.
            Maps to
            [AddressValidationMetadata](https://github.com/googlei18n/libaddres
            sinput/wiki/AddressValidationMetadata) and HTML 5.1 [Autofilling
            form controls: the autocomplete
            attribute](https://www.w3.org/TR/html51/sec-forms.html#autofilling-
            form-controls-the-autocomplete-attribute).

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "name": 'name',
        "last_digits": 'last_digits',
        "mtype": 'type',
        "brand": 'brand',
        "billing_address": 'billing_address'
    }

    _optionals = [
        'name',
        'last_digits',
        'mtype',
        'brand',
        'billing_address',
    ]

    def __init__(self,
                 name=APIHelper.SKIP,
                 last_digits=APIHelper.SKIP,
                 mtype=APIHelper.SKIP,
                 brand=APIHelper.SKIP,
                 billing_address=APIHelper.SKIP):
        """Constructor for the ApplePayCard class"""

        # Initialize members of the class
        if name is not APIHelper.SKIP:
            self.name = name 
        if last_digits is not APIHelper.SKIP:
            self.last_digits = last_digits 
        if mtype is not APIHelper.SKIP:
            self.mtype = mtype 
        if brand is not APIHelper.SKIP:
            self.brand = brand 
        if billing_address is not APIHelper.SKIP:
            self.billing_address = billing_address 

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """

        if dictionary is None:
            return None

        # Extract variables from the dictionary
        name = dictionary.get("name") if dictionary.get("name") else APIHelper.SKIP
        last_digits = dictionary.get("last_digits") if dictionary.get("last_digits") else APIHelper.SKIP
        mtype = dictionary.get("type") if dictionary.get("type") else APIHelper.SKIP
        brand = dictionary.get("brand") if dictionary.get("brand") else APIHelper.SKIP
        billing_address = Address.from_dictionary(dictionary.get('billing_address')) if 'billing_address' in dictionary.keys() else APIHelper.SKIP
        # Return an object of this model
        return cls(name,
                   last_digits,
                   mtype,
                   brand,
                   billing_address)



# -*- coding: utf-8 -*-

"""
paypalserversdk

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""
from paypalserversdk.api_helper import APIHelper


class Payee(object):

    """Implementation of the 'Payee' model.

    The merchant who receives the funds and fulfills the order. The merchant
    is also known as the payee., The details for the merchant who receives the
    funds and fulfills the order. The merchant is also known as the payee.

    Attributes:
        email_address (str): The internationalized email
            address.<blockquote><strong>Note:</strong> Up to 64 characters are
            allowed before and 255 characters are allowed after the
            <code>@</code> sign. However, the generally accepted maximum
            length for an email address is 254 characters. The pattern
            verifies that an unquoted <code>@</code> sign
            exists.</blockquote>
        merchant_id (str): The account identifier for a PayPal account.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "email_address": 'email_address',
        "merchant_id": 'merchant_id'
    }

    _optionals = [
        'email_address',
        'merchant_id',
    ]

    def __init__(self,
                 email_address=APIHelper.SKIP,
                 merchant_id=APIHelper.SKIP):
        """Constructor for the Payee class"""

        # Initialize members of the class
        if email_address is not APIHelper.SKIP:
            self.email_address = email_address 
        if merchant_id is not APIHelper.SKIP:
            self.merchant_id = merchant_id 

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """

        if dictionary is None:
            return None

        # Extract variables from the dictionary
        email_address = dictionary.get("email_address") if dictionary.get("email_address") else APIHelper.SKIP
        merchant_id = dictionary.get("merchant_id") if dictionary.get("merchant_id") else APIHelper.SKIP
        # Return an object of this model
        return cls(email_address,
                   merchant_id)



# -*- coding: utf-8 -*-

"""
paypalserversdk

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""
from paypalserversdk.api_helper import APIHelper
from paypalserversdk.models.pay_pal_wallet_customer_request import PayPalWalletCustomerRequest
from paypalserversdk.models.pay_pal_wallet_vault_instruction import PayPalWalletVaultInstruction


class PayPalWalletAttributes(object):

    """Implementation of the 'PayPal Wallet Attributes' model.

    Additional attributes associated with the use of this PayPal Wallet.

    Attributes:
        customer (PayPalWalletCustomerRequest): TODO: type description here.
        vault (PayPalWalletVaultInstruction): TODO: type description here.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "customer": 'customer',
        "vault": 'vault'
    }

    _optionals = [
        'customer',
        'vault',
    ]

    def __init__(self,
                 customer=APIHelper.SKIP,
                 vault=APIHelper.SKIP):
        """Constructor for the PayPalWalletAttributes class"""

        # Initialize members of the class
        if customer is not APIHelper.SKIP:
            self.customer = customer 
        if vault is not APIHelper.SKIP:
            self.vault = vault 

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """

        if dictionary is None:
            return None

        # Extract variables from the dictionary
        customer = PayPalWalletCustomerRequest.from_dictionary(dictionary.get('customer')) if 'customer' in dictionary.keys() else APIHelper.SKIP
        vault = PayPalWalletVaultInstruction.from_dictionary(dictionary.get('vault')) if 'vault' in dictionary.keys() else APIHelper.SKIP
        # Return an object of this model
        return cls(customer,
                   vault)



# -*- coding: utf-8 -*-

"""
paypalserversdk

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class PayPalPaymentTokenUsageType(object):

    """Implementation of the 'PayPal Payment Token Usage Type' enum.

    The usage type associated with the PayPal payment token.

    Attributes:
        MERCHANT: TODO: type description here.
        PLATFORM: TODO: type description here.

    """
    MERCHANT = 'MERCHANT'

    PLATFORM = 'PLATFORM'




# -*- coding: utf-8 -*-

"""
paypalserversdk

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""
from paypalserversdk.api_helper import APIHelper
from paypalserversdk.models.refund_platform_fee import RefundPlatformFee


class RefundPaymentInstruction(object):

    """Implementation of the 'Refund Payment Instruction' model.

    Any additional payments instructions during refund payment processing.
    This object is only applicable to merchants that have been enabled for
    PayPal Commerce Platform for Marketplaces and Platforms capability. Please
    speak to your account manager if you want to use this capability.

    Attributes:
        platform_fees (List[RefundPlatformFee]): Specifies the amount that the
            API caller will contribute to the refund being processed. The
            amount needs to be lower than platform_fees amount originally
            captured or the amount that is remaining if multiple refunds have
            been processed. This field is only applicable to merchants that
            have been enabled for PayPal Commerce Platform for Marketplaces
            and Platforms capability. Please speak to your account manager if
            you want to use this capability.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "platform_fees": 'platform_fees'
    }

    _optionals = [
        'platform_fees',
    ]

    def __init__(self,
                 platform_fees=APIHelper.SKIP):
        """Constructor for the RefundPaymentInstruction class"""

        # Initialize members of the class
        if platform_fees is not APIHelper.SKIP:
            self.platform_fees = platform_fees 

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """

        if dictionary is None:
            return None

        # Extract variables from the dictionary
        platform_fees = None
        if dictionary.get('platform_fees') is not None:
            platform_fees = [RefundPlatformFee.from_dictionary(x) for x in dictionary.get('platform_fees')]
        else:
            platform_fees = APIHelper.SKIP
        # Return an object of this model
        return cls(platform_fees)



# -*- coding: utf-8 -*-

"""
paypalserversdk

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class BLIKLevel0PaymentObject(object):

    """Implementation of the 'BLIK Level_0 Payment Object' model.

    Information used to pay using BLIK level_0 flow.

    Attributes:
        auth_code (str): The 6-digit code used to authenticate a consumer
            within BLIK.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "auth_code": 'auth_code'
    }

    def __init__(self,
                 auth_code=None):
        """Constructor for the BLIKLevel0PaymentObject class"""

        # Initialize members of the class
        self.auth_code = auth_code 

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """

        if dictionary is None:
            return None

        # Extract variables from the dictionary
        auth_code = dictionary.get("auth_code") if dictionary.get("auth_code") else None
        # Return an object of this model
        return cls(auth_code)



# -*- coding: utf-8 -*-

"""
paypalserversdk

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class ApplePayPaymentDataType(object):

    """Implementation of the 'Apple Pay Payment Data Type' enum.

    Indicates the type of payment data passed, in case of Non China the
    payment data is 3DSECURE and for China it is EMV.

    Attributes:
        ENUM_3DSECURE: TODO: type description here.
        EMV: TODO: type description here.

    """
    ENUM_3DSECURE = '3DSECURE'

    EMV = 'EMV'




# -*- coding: utf-8 -*-

"""
paypalserversdk

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""
from paypalserversdk.api_helper import APIHelper
from paypalserversdk.models.card_verification_processor_response import CardVerificationProcessorResponse
from paypalserversdk.models.money import Money


class CardVerificationDetails(object):

    """Implementation of the 'Card Verification Details' model.

    Card Verification details including the authorization details and 3D
    SECURE details.

    Attributes:
        network_transaction_id (str): Transaction Identifier as given by the
            network to indicate a previously executed CIT authorization. Only
            present when authorization is successful for a verification.
        date (str): The date that the transaction was authorized by the
            scheme. This field may not be returned for all networks.
            MasterCard refers to this field as "BankNet reference date".
        network (CardBrand): The card network or brand. Applies to credit,
            debit, gift, and payment cards.
        time (str): The date and time, in [Internet date and time
            format](https://tools.ietf.org/html/rfc3339#section-5.6). Seconds
            are required while fractional seconds are
            optional.<blockquote><strong>Note:</strong> The regular expression
            provides guidance but does not reject all invalid
            dates.</blockquote>
        amount (Money): The currency and amount for a financial transaction,
            such as a balance or payment due.
        processor_response (CardVerificationProcessorResponse): The processor
            response information for payment requests, such as direct credit
            card transactions.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "network_transaction_id": 'network_transaction_id',
        "date": 'date',
        "network": 'network',
        "time": 'time',
        "amount": 'amount',
        "processor_response": 'processor_response'
    }

    _optionals = [
        'network_transaction_id',
        'date',
        'network',
        'time',
        'amount',
        'processor_response',
    ]

    def __init__(self,
                 network_transaction_id=APIHelper.SKIP,
                 date=APIHelper.SKIP,
                 network=APIHelper.SKIP,
                 time=APIHelper.SKIP,
                 amount=APIHelper.SKIP,
                 processor_response=APIHelper.SKIP):
        """Constructor for the CardVerificationDetails class"""

        # Initialize members of the class
        if network_transaction_id is not APIHelper.SKIP:
            self.network_transaction_id = network_transaction_id 
        if date is not APIHelper.SKIP:
            self.date = date 
        if network is not APIHelper.SKIP:
            self.network = network 
        if time is not APIHelper.SKIP:
            self.time = time 
        if amount is not APIHelper.SKIP:
            self.amount = amount 
        if processor_response is not APIHelper.SKIP:
            self.processor_response = processor_response 

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """

        if dictionary is None:
            return None

        # Extract variables from the dictionary
        network_transaction_id = dictionary.get("network_transaction_id") if dictionary.get("network_transaction_id") else APIHelper.SKIP
        date = dictionary.get("date") if dictionary.get("date") else APIHelper.SKIP
        network = dictionary.get("network") if dictionary.get("network") else APIHelper.SKIP
        time = dictionary.get("time") if dictionary.get("time") else APIHelper.SKIP
        amount = Money.from_dictionary(dictionary.get('amount')) if 'amount' in dictionary.keys() else APIHelper.SKIP
        processor_response = CardVerificationProcessorResponse.from_dictionary(dictionary.get('processor_response')) if 'processor_response' in dictionary.keys() else APIHelper.SKIP
        # Return an object of this model
        return cls(network_transaction_id,
                   date,
                   network,
                   time,
                   amount,
                   processor_response)



# -*- coding: utf-8 -*-

"""
paypalserversdk

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class AuthorizationIncompleteReason(object):

    """Implementation of the 'Authorization Incomplete Reason' enum.

    The reason why the authorized status is `PENDING`.

    Attributes:
        PENDING_REVIEW: TODO: type description here.
        DECLINED_BY_RISK_FRAUD_FILTERS: TODO: type description here.

    """
    PENDING_REVIEW = 'PENDING_REVIEW'

    DECLINED_BY_RISK_FRAUD_FILTERS = 'DECLINED_BY_RISK_FRAUD_FILTERS'




# -*- coding: utf-8 -*-

"""
paypalserversdk

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""
from paypalserversdk.api_helper import APIHelper


class Name(object):

    """Implementation of the 'Name' model.

    The name of the party.

    Attributes:
        given_name (str): When the party is a person, the party's given, or
            first, name.
        surname (str): When the party is a person, the party's surname or
            family name. Also known as the last name. Required when the party
            is a person. Use also to store multiple surnames including the
            matronymic, or mother's, surname.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "given_name": 'given_name',
        "surname": 'surname'
    }

    _optionals = [
        'given_name',
        'surname',
    ]

    def __init__(self,
                 given_name=APIHelper.SKIP,
                 surname=APIHelper.SKIP):
        """Constructor for the Name class"""

        # Initialize members of the class
        if given_name is not APIHelper.SKIP:
            self.given_name = given_name 
        if surname is not APIHelper.SKIP:
            self.surname = surname 

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """

        if dictionary is None:
            return None

        # Extract variables from the dictionary
        given_name = dictionary.get("given_name") if dictionary.get("given_name") else APIHelper.SKIP
        surname = dictionary.get("surname") if dictionary.get("surname") else APIHelper.SKIP
        # Return an object of this model
        return cls(given_name,
                   surname)



# -*- coding: utf-8 -*-

"""
paypalserversdk

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class CVVCode(object):

    """Implementation of the 'CVV Code' enum.

    The card verification value code for for Visa, Discover, Mastercard, or
    American Express.

    Attributes:
        E: TODO: type description here.
        I: TODO: type description here.
        M: TODO: type description here.
        N: TODO: type description here.
        P: TODO: type description here.
        S: TODO: type description here.
        U: TODO: type description here.
        X: TODO: type description here.
        ENUM_ALL OTHERS: TODO: type description here.
        ENUM_0: TODO: type description here.
        ENUM_1: TODO: type description here.
        ENUM_2: TODO: type description here.
        ENUM_3: TODO: type description here.
        ENUM_4: TODO: type description here.

    """
    E = 'E'

    I = 'I'

    M = 'M'

    N = 'N'

    P = 'P'

    S = 'S'

    U = 'U'

    X = 'X'

    ENUM_ALL_OTHERS = 'All others'

    ENUM_0 = '0'

    ENUM_1 = '1'

    ENUM_2 = '2'

    ENUM_3 = '3'

    ENUM_4 = '4'




# -*- coding: utf-8 -*-

"""
paypalserversdk

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class VaultInstruction(object):

    """Implementation of the 'Vault Instruction' model.

    Base vaulting specification. The object can be extended for specific use
    cases within each payment_source that supports vaulting.

    Attributes:
        store_in_vault (StoreInVaultInstruction): Defines how and when the
            payment source gets vaulted.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "store_in_vault": 'store_in_vault'
    }

    def __init__(self,
                 store_in_vault=None):
        """Constructor for the VaultInstruction class"""

        # Initialize members of the class
        self.store_in_vault = store_in_vault 

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """

        if dictionary is None:
            return None

        # Extract variables from the dictionary
        store_in_vault = dictionary.get("store_in_vault") if dictionary.get("store_in_vault") else None
        # Return an object of this model
        return cls(store_in_vault)



# -*- coding: utf-8 -*-

"""
paypalserversdk

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class TokenRequestType(object):

    """Implementation of the 'Token Request Type' enum.

    The tokenization method that generated the ID.

    Attributes:
        SETUP_TOKEN: TODO: type description here.
        BILLING_AGREEMENT: TODO: type description here.

    """
    SETUP_TOKEN = 'SETUP_TOKEN'

    BILLING_AGREEMENT = 'BILLING_AGREEMENT'




# -*- coding: utf-8 -*-

"""
paypalserversdk

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""
from paypalserversdk.api_helper import APIHelper


class ThreeDSecureAuthenticationResponse(object):

    """Implementation of the 'Three-D Secure Authentication Response' model.

    Results of 3D Secure Authentication.

    Attributes:
        authentication_status (PAResStatus): Transactions status result
            identifier. The outcome of the issuer's authentication.
        enrollment_status (EnrollmentStatus): Status of Authentication
            eligibility.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "authentication_status": 'authentication_status',
        "enrollment_status": 'enrollment_status'
    }

    _optionals = [
        'authentication_status',
        'enrollment_status',
    ]

    def __init__(self,
                 authentication_status=APIHelper.SKIP,
                 enrollment_status=APIHelper.SKIP):
        """Constructor for the ThreeDSecureAuthenticationResponse class"""

        # Initialize members of the class
        if authentication_status is not APIHelper.SKIP:
            self.authentication_status = authentication_status 
        if enrollment_status is not APIHelper.SKIP:
            self.enrollment_status = enrollment_status 

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """

        if dictionary is None:
            return None

        # Extract variables from the dictionary
        authentication_status = dictionary.get("authentication_status") if dictionary.get("authentication_status") else APIHelper.SKIP
        enrollment_status = dictionary.get("enrollment_status") if dictionary.get("enrollment_status") else APIHelper.SKIP
        # Return an object of this model
        return cls(authentication_status,
                   enrollment_status)



# -*- coding: utf-8 -*-

"""
paypalserversdk

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""

from apimatic_core.configurations.global_configuration import GlobalConfiguration
from apimatic_core.decorators.lazy_property import LazyProperty
from paypalserversdk.configuration import Configuration
from paypalserversdk.controllers.base_controller import BaseController
from paypalserversdk.configuration import Environment
from paypalserversdk.http.auth.o_auth_2 import OAuth2
from paypalserversdk.controllers.orders_controller import OrdersController
from paypalserversdk.controllers.payments_controller import PaymentsController
from paypalserversdk.controllers.vault_controller import VaultController
from paypalserversdk.controllers.o_auth_authorization_controller\
    import OAuthAuthorizationController


class PaypalserversdkClient(object):
    @LazyProperty
    def orders(self):
        return OrdersController(self.global_configuration)

    @LazyProperty
    def payments(self):
        return PaymentsController(self.global_configuration)

    @LazyProperty
    def vault(self):
        return VaultController(self.global_configuration)

    @LazyProperty
    def o_auth_authorization(self):
        return OAuthAuthorizationController(self.global_configuration)

    @property
    def oauth_2(self):
        return self.auth_managers['Oauth2']

    def __init__(self, http_client_instance=None,
                 override_http_client_configuration=False, http_call_back=None,
                 timeout=60, max_retries=0, backoff_factor=2,
                 retry_statuses=None, retry_methods=None,
                 logging_configuration=None, environment=Environment.SANDBOX,
                 client_credentials_auth_credentials=None, config=None):
        self.config = config or Configuration(
            http_client_instance=http_client_instance,
            override_http_client_configuration=override_http_client_configuration,
            http_call_back=http_call_back, timeout=timeout,
            max_retries=max_retries, backoff_factor=backoff_factor,
            retry_statuses=retry_statuses, retry_methods=retry_methods,
            logging_configuration=logging_configuration,
            environment=environment,
            client_credentials_auth_credentials=client_credentials_auth_credentials)

        self.global_configuration = GlobalConfiguration(self.config)\
            .global_errors(BaseController.global_errors())\
            .base_uri_executor(self.config.get_base_uri)\
            .user_agent(BaseController.user_agent(), BaseController.user_agent_parameters())

        self.auth_managers = {key: None for key in ['Oauth2']}
        self.auth_managers['Oauth2'] = OAuth2(
            self.config.client_credentials_auth_credentials,
            self.global_configuration)
        self.global_configuration = self.global_configuration.auth_managers(self.auth_managers)




# -*- coding: utf-8 -*-

"""
paypalserversdk

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""
from paypalserversdk.api_helper import APIHelper
from paypalserversdk.models.level_2_card_processing_data import Level2CardProcessingData
from paypalserversdk.models.level_3_card_processing_data import Level3CardProcessingData


class CardSupplementaryData(object):

    """Implementation of the 'Card Supplementary Data' model.

    Merchants and partners can add Level 2 and 3 data to payments to reduce
    risk and payment processing costs. For more information about processing
    payments, see <a
    href="https://developer.paypal.com/docs/checkout/advanced/processing/">chec
    kout</a> or <a
    href="https://developer.paypal.com/docs/multiparty/checkout/advanced/proces
    sing/">multiparty checkout</a>.

    Attributes:
        level_2 (Level2CardProcessingData): The level 2 card processing data
            collections. If your merchant account has been configured for
            Level 2 processing this field will be passed to the processor on
            your behalf. Please contact your PayPal Technical Account Manager
            to define level 2 data for your business.
        level_3 (Level3CardProcessingData): The level 3 card processing data
            collections, If your merchant account has been configured for
            Level 3 processing this field will be passed to the processor on
            your behalf. Please contact your PayPal Technical Account Manager
            to define level 3 data for your business.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "level_2": 'level_2',
        "level_3": 'level_3'
    }

    _optionals = [
        'level_2',
        'level_3',
    ]

    def __init__(self,
                 level_2=APIHelper.SKIP,
                 level_3=APIHelper.SKIP):
        """Constructor for the CardSupplementaryData class"""

        # Initialize members of the class
        if level_2 is not APIHelper.SKIP:
            self.level_2 = level_2 
        if level_3 is not APIHelper.SKIP:
            self.level_3 = level_3 

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """

        if dictionary is None:
            return None

        # Extract variables from the dictionary
        level_2 = Level2CardProcessingData.from_dictionary(dictionary.get('level_2')) if 'level_2' in dictionary.keys() else APIHelper.SKIP
        level_3 = Level3CardProcessingData.from_dictionary(dictionary.get('level_3')) if 'level_3' in dictionary.keys() else APIHelper.SKIP
        # Return an object of this model
        return cls(level_2,
                   level_3)



# -*- coding: utf-8 -*-

"""
paypalserversdk

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""
from paypalserversdk.api_helper import APIHelper
from paypalserversdk.models.assurance_details import AssuranceDetails
from paypalserversdk.models.google_pay_card_attributes import GooglePayCardAttributes
from paypalserversdk.models.google_pay_decrypted_token_data import GooglePayDecryptedTokenData
from paypalserversdk.models.google_pay_request_card import GooglePayRequestCard
from paypalserversdk.models.phone_number_with_country_code import PhoneNumberWithCountryCode


class GooglePayRequest(object):

    """Implementation of the 'Google Pay Request' model.

    Information needed to pay using Google Pay.

    Attributes:
        name (str): The full name representation like Mr J Smith.
        email_address (str): The internationalized email
            address.<blockquote><strong>Note:</strong> Up to 64 characters are
            allowed before and 255 characters are allowed after the
            <code>@</code> sign. However, the generally accepted maximum
            length for an email address is 254 characters. The pattern
            verifies that an unquoted <code>@</code> sign
            exists.</blockquote>
        phone_number (PhoneNumberWithCountryCode): The phone number in its
            canonical international [E.164 numbering plan
            format](https://www.itu.int/rec/T-REC-E.164/en).
        card (GooglePayRequestCard): The payment card used to fund a Google
            Pay payment. Can be a credit or debit card.
        decrypted_token (GooglePayDecryptedTokenData): Details shared by
            Google for the merchant to be shared with PayPal. This is required
            to process the transaction using the Google Pay payment method.
        assurance_details (AssuranceDetails): Information about cardholder
            possession validation and cardholder identification and
            verifications (ID&V).
        attributes (GooglePayCardAttributes): Additional attributes associated
            with the use of this card.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "name": 'name',
        "email_address": 'email_address',
        "phone_number": 'phone_number',
        "card": 'card',
        "decrypted_token": 'decrypted_token',
        "assurance_details": 'assurance_details',
        "attributes": 'attributes'
    }

    _optionals = [
        'name',
        'email_address',
        'phone_number',
        'card',
        'decrypted_token',
        'assurance_details',
        'attributes',
    ]

    def __init__(self,
                 name=APIHelper.SKIP,
                 email_address=APIHelper.SKIP,
                 phone_number=APIHelper.SKIP,
                 card=APIHelper.SKIP,
                 decrypted_token=APIHelper.SKIP,
                 assurance_details=APIHelper.SKIP,
                 attributes=APIHelper.SKIP):
        """Constructor for the GooglePayRequest class"""

        # Initialize members of the class
        if name is not APIHelper.SKIP:
            self.name = name 
        if email_address is not APIHelper.SKIP:
            self.email_address = email_address 
        if phone_number is not APIHelper.SKIP:
            self.phone_number = phone_number 
        if card is not APIHelper.SKIP:
            self.card = card 
        if decrypted_token is not APIHelper.SKIP:
            self.decrypted_token = decrypted_token 
        if assurance_details is not APIHelper.SKIP:
            self.assurance_details = assurance_details 
        if attributes is not APIHelper.SKIP:
            self.attributes = attributes 

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """

        if dictionary is None:
            return None

        # Extract variables from the dictionary
        name = dictionary.get("name") if dictionary.get("name") else APIHelper.SKIP
        email_address = dictionary.get("email_address") if dictionary.get("email_address") else APIHelper.SKIP
        phone_number = PhoneNumberWithCountryCode.from_dictionary(dictionary.get('phone_number')) if 'phone_number' in dictionary.keys() else APIHelper.SKIP
        card = GooglePayRequestCard.from_dictionary(dictionary.get('card')) if 'card' in dictionary.keys() else APIHelper.SKIP
        decrypted_token = GooglePayDecryptedTokenData.from_dictionary(dictionary.get('decrypted_token')) if 'decrypted_token' in dictionary.keys() else APIHelper.SKIP
        assurance_details = AssuranceDetails.from_dictionary(dictionary.get('assurance_details')) if 'assurance_details' in dictionary.keys() else APIHelper.SKIP
        attributes = GooglePayCardAttributes.from_dictionary(dictionary.get('attributes')) if 'attributes' in dictionary.keys() else APIHelper.SKIP
        # Return an object of this model
        return cls(name,
                   email_address,
                   phone_number,
                   card,
                   decrypted_token,
                   assurance_details,
                   attributes)



# -*- coding: utf-8 -*-

"""
paypalserversdk

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""
from paypalserversdk.api_helper import APIHelper
from paypalserversdk.models.link_description import LinkDescription
from paypalserversdk.models.payer import Payer
from paypalserversdk.models.payment_source_response import PaymentSourceResponse
from paypalserversdk.models.purchase_unit import PurchaseUnit


class Order(object):

    """Implementation of the 'Order' model.

    The order details.

    Attributes:
        create_time (str): The date and time, in [Internet date and time
            format](https://tools.ietf.org/html/rfc3339#section-5.6). Seconds
            are required while fractional seconds are
            optional.<blockquote><strong>Note:</strong> The regular expression
            provides guidance but does not reject all invalid
            dates.</blockquote>
        update_time (str): The date and time, in [Internet date and time
            format](https://tools.ietf.org/html/rfc3339#section-5.6). Seconds
            are required while fractional seconds are
            optional.<blockquote><strong>Note:</strong> The regular expression
            provides guidance but does not reject all invalid
            dates.</blockquote>
        id (str): The ID of the order.
        payment_source (PaymentSourceResponse): The payment source used to
            fund the payment.
        intent (CheckoutPaymentIntent): The intent to either capture payment
            immediately or authorize a payment for an order after order
            creation.
        processing_instruction (ProcessingInstruction): The instruction to
            process an order.
        payer (Payer): TODO: type description here.
        purchase_units (List[PurchaseUnit]): An array of purchase units. Each
            purchase unit establishes a contract between a customer and
            merchant. Each purchase unit represents either a full or partial
            order that the customer intends to purchase from the merchant.
        status (OrderStatus): The order status.
        links (List[LinkDescription]): An array of request-related HATEOAS
            links. To complete payer approval, use the `approve` link to
            redirect the payer. The API caller has 3 hours (default setting,
            this which can be changed by your account manager to 24/48/72
            hours to accommodate your use case) from the time the order is
            created, to redirect your payer. Once redirected, the API caller
            has 3 hours for the payer to approve the order and either
            authorize or capture the order. If you are not using the PayPal
            JavaScript SDK to initiate PayPal Checkout (in context) ensure
            that you include `application_context.return_url` is specified or
            you will get "We're sorry, Things don't appear to be working at
            the moment" after the payer approves the payment.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "create_time": 'create_time',
        "update_time": 'update_time',
        "id": 'id',
        "payment_source": 'payment_source',
        "intent": 'intent',
        "processing_instruction": 'processing_instruction',
        "payer": 'payer',
        "purchase_units": 'purchase_units',
        "status": 'status',
        "links": 'links'
    }

    _optionals = [
        'create_time',
        'update_time',
        'id',
        'payment_source',
        'intent',
        'processing_instruction',
        'payer',
        'purchase_units',
        'status',
        'links',
    ]

    def __init__(self,
                 create_time=APIHelper.SKIP,
                 update_time=APIHelper.SKIP,
                 id=APIHelper.SKIP,
                 payment_source=APIHelper.SKIP,
                 intent=APIHelper.SKIP,
                 processing_instruction='NO_INSTRUCTION',
                 payer=APIHelper.SKIP,
                 purchase_units=APIHelper.SKIP,
                 status=APIHelper.SKIP,
                 links=APIHelper.SKIP):
        """Constructor for the Order class"""

        # Initialize members of the class
        if create_time is not APIHelper.SKIP:
            self.create_time = create_time 
        if update_time is not APIHelper.SKIP:
            self.update_time = update_time 
        if id is not APIHelper.SKIP:
            self.id = id 
        if payment_source is not APIHelper.SKIP:
            self.payment_source = payment_source 
        if intent is not APIHelper.SKIP:
            self.intent = intent 
        self.processing_instruction = processing_instruction 
        if payer is not APIHelper.SKIP:
            self.payer = payer 
        if purchase_units is not APIHelper.SKIP:
            self.purchase_units = purchase_units 
        if status is not APIHelper.SKIP:
            self.status = status 
        if links is not APIHelper.SKIP:
            self.links = links 

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """

        if dictionary is None:
            return None

        # Extract variables from the dictionary
        create_time = dictionary.get("create_time") if dictionary.get("create_time") else APIHelper.SKIP
        update_time = dictionary.get("update_time") if dictionary.get("update_time") else APIHelper.SKIP
        id = dictionary.get("id") if dictionary.get("id") else APIHelper.SKIP
        payment_source = PaymentSourceResponse.from_dictionary(dictionary.get('payment_source')) if 'payment_source' in dictionary.keys() else APIHelper.SKIP
        intent = dictionary.get("intent") if dictionary.get("intent") else APIHelper.SKIP
        processing_instruction = dictionary.get("processing_instruction") if dictionary.get("processing_instruction") else 'NO_INSTRUCTION'
        payer = Payer.from_dictionary(dictionary.get('payer')) if 'payer' in dictionary.keys() else APIHelper.SKIP
        purchase_units = None
        if dictionary.get('purchase_units') is not None:
            purchase_units = [PurchaseUnit.from_dictionary(x) for x in dictionary.get('purchase_units')]
        else:
            purchase_units = APIHelper.SKIP
        status = dictionary.get("status") if dictionary.get("status") else APIHelper.SKIP
        links = None
        if dictionary.get('links') is not None:
            links = [LinkDescription.from_dictionary(x) for x in dictionary.get('links')]
        else:
            links = APIHelper.SKIP
        # Return an object of this model
        return cls(create_time,
                   update_time,
                   id,
                   payment_source,
                   intent,
                   processing_instruction,
                   payer,
                   purchase_units,
                   status,
                   links)



# -*- coding: utf-8 -*-

"""
paypalserversdk

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""
from paypalserversdk.api_helper import APIHelper


class AssuranceDetails(object):

    """Implementation of the 'Assurance Details' model.

    Information about cardholder possession validation and cardholder
    identification and verifications (ID&V).

    Attributes:
        account_verified (bool): If true, indicates that Cardholder possession
            validation has been performed on returned payment credential.
        card_holder_authenticated (bool): If true, indicates that
            identification and verifications (ID&V) was performed on the
            returned payment credential.If false, the same risk-based
            authentication can be performed as you would for card
            transactions. This risk-based authentication can include, but not
            limited to, step-up with 3D Secure protocol if applicable.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "account_verified": 'account_verified',
        "card_holder_authenticated": 'card_holder_authenticated'
    }

    _optionals = [
        'account_verified',
        'card_holder_authenticated',
    ]

    def __init__(self,
                 account_verified=False,
                 card_holder_authenticated=False):
        """Constructor for the AssuranceDetails class"""

        # Initialize members of the class
        self.account_verified = account_verified 
        self.card_holder_authenticated = card_holder_authenticated 

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """

        if dictionary is None:
            return None

        # Extract variables from the dictionary
        account_verified = dictionary.get("account_verified") if dictionary.get("account_verified") else False
        card_holder_authenticated = dictionary.get("card_holder_authenticated") if dictionary.get("card_holder_authenticated") else False
        # Return an object of this model
        return cls(account_verified,
                   card_holder_authenticated)



# -*- coding: utf-8 -*-

"""
paypalserversdk

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class ECIFlag(object):

    """Implementation of the 'ECI Flag' enum.

    Electronic Commerce Indicator (ECI). The ECI value is part of the 2 data
    elements that indicate the transaction was processed electronically. This
    should be passed on the authorization transaction to the
    Gateway/Processor.

    Attributes:
        MASTERCARD_NON_3D_SECURE_TRANSACTION: TODO: type description here.
        MASTERCARD_ATTEMPTED_AUTHENTICATION_TRANSACTION: TODO: type
            description here.
        MASTERCARD_FULLY_AUTHENTICATED_TRANSACTION: TODO: type description
            here.
        FULLY_AUTHENTICATED_TRANSACTION: TODO: type description here.
        ATTEMPTED_AUTHENTICATION_TRANSACTION: TODO: type description here.
        NON_3D_SECURE_TRANSACTION: TODO: type description here.

    """
    MASTERCARD_NON_3D_SECURE_TRANSACTION = 'MASTERCARD_NON_3D_SECURE_TRANSACTION'

    MASTERCARD_ATTEMPTED_AUTHENTICATION_TRANSACTION = 'MASTERCARD_ATTEMPTED_AUTHENTICATION_TRANSACTION'

    MASTERCARD_FULLY_AUTHENTICATED_TRANSACTION = 'MASTERCARD_FULLY_AUTHENTICATED_TRANSACTION'

    FULLY_AUTHENTICATED_TRANSACTION = 'FULLY_AUTHENTICATED_TRANSACTION'

    ATTEMPTED_AUTHENTICATION_TRANSACTION = 'ATTEMPTED_AUTHENTICATION_TRANSACTION'

    NON_3D_SECURE_TRANSACTION = 'NON_3D_SECURE_TRANSACTION'




# -*- coding: utf-8 -*-

"""
paypalserversdk

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""
from paypalserversdk.api_helper import APIHelper
from paypalserversdk.models.related_identifiers import RelatedIdentifiers


class PaymentSupplementaryData(object):

    """Implementation of the 'Payment Supplementary Data' model.

    The supplementary data.

    Attributes:
        related_ids (RelatedIdentifiers): Identifiers related to a specific
            resource.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "related_ids": 'related_ids'
    }

    _optionals = [
        'related_ids',
    ]

    def __init__(self,
                 related_ids=APIHelper.SKIP):
        """Constructor for the PaymentSupplementaryData class"""

        # Initialize members of the class
        if related_ids is not APIHelper.SKIP:
            self.related_ids = related_ids 

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """

        if dictionary is None:
            return None

        # Extract variables from the dictionary
        related_ids = RelatedIdentifiers.from_dictionary(dictionary.get('related_ids')) if 'related_ids' in dictionary.keys() else APIHelper.SKIP
        # Return an object of this model
        return cls(related_ids)



# -*- coding: utf-8 -*-

"""
paypalserversdk

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class PayPalWalletAccountVerificationStatus(object):

    """Implementation of the 'PayPal Wallet Account Verification Status' enum.

    The account status indicates whether the buyer has verified the financial
    details associated with their PayPal account.

    Attributes:
        VERIFIED: TODO: type description here.
        UNVERIFIED: TODO: type description here.

    """
    VERIFIED = 'VERIFIED'

    UNVERIFIED = 'UNVERIFIED'




# -*- coding: utf-8 -*-

"""
paypalserversdk

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class PayPalExperienceUserAction(object):

    """Implementation of the 'PayPal Experience User Action' enum.

    Configures a <strong>Continue</strong> or <strong>Pay Now</strong>
    checkout flow.

    Attributes:
        CONTINUE: TODO: type description here.
        PAY_NOW: TODO: type description here.

    """
    CONTINUE = 'CONTINUE'

    PAY_NOW = 'PAY_NOW'




# -*- coding: utf-8 -*-

"""
paypalserversdk

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""
from paypalserversdk.api_helper import APIHelper
from paypalserversdk.models.apple_pay_attributes import ApplePayAttributes
from paypalserversdk.models.apple_pay_decrypted_token_data import ApplePayDecryptedTokenData
from paypalserversdk.models.card_stored_credential import CardStoredCredential
from paypalserversdk.models.phone_number import PhoneNumber


class ApplePayRequest(object):

    """Implementation of the 'Apple Pay Request' model.

    Information needed to pay using ApplePay.

    Attributes:
        id (str): ApplePay transaction identifier, this will be the unique
            identifier for this transaction provided by Apple. The pattern is
            defined by an external party and supports Unicode.
        name (str): The full name representation like Mr J Smith.
        email_address (str): The internationalized email
            address.<blockquote><strong>Note:</strong> Up to 64 characters are
            allowed before and 255 characters are allowed after the
            <code>@</code> sign. However, the generally accepted maximum
            length for an email address is 254 characters. The pattern
            verifies that an unquoted <code>@</code> sign
            exists.</blockquote>
        phone_number (PhoneNumber): The phone number in its canonical
            international [E.164 numbering plan
            format](https://www.itu.int/rec/T-REC-E.164/en).
        decrypted_token (ApplePayDecryptedTokenData): Information about the
            Payment data obtained by decrypting Apple Pay token.
        stored_credential (CardStoredCredential): Provides additional details
            to process a payment using a `card` that has been stored or is
            intended to be stored (also referred to as stored_credential or
            card-on-file).<br/>Parameter
            compatibility:<br/><ul><li>`payment_type=ONE_TIME` is compatible
            only with `payment_initiator=CUSTOMER`.</li><li>`usage=FIRST` is
            compatible only with
            `payment_initiator=CUSTOMER`.</li><li>`previous_transaction_referen
            ce` or `previous_network_transaction_reference` is compatible only
            with `payment_initiator=MERCHANT`.</li><li>Only one of the
            parameters - `previous_transaction_reference` and
            `previous_network_transaction_reference` - can be present in the
            request.</li></ul>
        vault_id (str): The PayPal-generated ID for the vaulted payment
            source. This ID should be stored on the merchant's server so the
            saved payment source can be used for future transactions.
        attributes (ApplePayAttributes): Additional attributes associated with
            apple pay.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "id": 'id',
        "name": 'name',
        "email_address": 'email_address',
        "phone_number": 'phone_number',
        "decrypted_token": 'decrypted_token',
        "stored_credential": 'stored_credential',
        "vault_id": 'vault_id',
        "attributes": 'attributes'
    }

    _optionals = [
        'id',
        'name',
        'email_address',
        'phone_number',
        'decrypted_token',
        'stored_credential',
        'vault_id',
        'attributes',
    ]

    def __init__(self,
                 id=APIHelper.SKIP,
                 name=APIHelper.SKIP,
                 email_address=APIHelper.SKIP,
                 phone_number=APIHelper.SKIP,
                 decrypted_token=APIHelper.SKIP,
                 stored_credential=APIHelper.SKIP,
                 vault_id=APIHelper.SKIP,
                 attributes=APIHelper.SKIP):
        """Constructor for the ApplePayRequest class"""

        # Initialize members of the class
        if id is not APIHelper.SKIP:
            self.id = id 
        if name is not APIHelper.SKIP:
            self.name = name 
        if email_address is not APIHelper.SKIP:
            self.email_address = email_address 
        if phone_number is not APIHelper.SKIP:
            self.phone_number = phone_number 
        if decrypted_token is not APIHelper.SKIP:
            self.decrypted_token = decrypted_token 
        if stored_credential is not APIHelper.SKIP:
            self.stored_credential = stored_credential 
        if vault_id is not APIHelper.SKIP:
            self.vault_id = vault_id 
        if attributes is not APIHelper.SKIP:
            self.attributes = attributes 

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """

        if dictionary is None:
            return None

        # Extract variables from the dictionary
        id = dictionary.get("id") if dictionary.get("id") else APIHelper.SKIP
        name = dictionary.get("name") if dictionary.get("name") else APIHelper.SKIP
        email_address = dictionary.get("email_address") if dictionary.get("email_address") else APIHelper.SKIP
        phone_number = PhoneNumber.from_dictionary(dictionary.get('phone_number')) if 'phone_number' in dictionary.keys() else APIHelper.SKIP
        decrypted_token = ApplePayDecryptedTokenData.from_dictionary(dictionary.get('decrypted_token')) if 'decrypted_token' in dictionary.keys() else APIHelper.SKIP
        stored_credential = CardStoredCredential.from_dictionary(dictionary.get('stored_credential')) if 'stored_credential' in dictionary.keys() else APIHelper.SKIP
        vault_id = dictionary.get("vault_id") if dictionary.get("vault_id") else APIHelper.SKIP
        attributes = ApplePayAttributes.from_dictionary(dictionary.get('attributes')) if 'attributes' in dictionary.keys() else APIHelper.SKIP
        # Return an object of this model
        return cls(id,
                   name,
                   email_address,
                   phone_number,
                   decrypted_token,
                   stored_credential,
                   vault_id,
                   attributes)



# -*- coding: utf-8 -*-

"""
paypalserversdk

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""
from paypalserversdk.api_helper import APIHelper
from paypalserversdk.models.authorization_status_details import AuthorizationStatusDetails
from paypalserversdk.models.link_description import LinkDescription
from paypalserversdk.models.money import Money
from paypalserversdk.models.network_transaction_reference import NetworkTransactionReference
from paypalserversdk.models.processor_response import ProcessorResponse
from paypalserversdk.models.seller_protection import SellerProtection


class AuthorizationWithAdditionalData(object):

    """Implementation of the 'Authorization With Additional Data' model.

    The authorization with additional payment details, such as risk assessment
    and processor response. These details are populated only for certain
    payment methods.

    Attributes:
        status (AuthorizationStatus): The status for the authorized payment.
        status_details (AuthorizationStatusDetails): The details of the
            authorized payment status.
        id (str): The PayPal-generated ID for the authorized payment.
        amount (Money): The currency and amount for a financial transaction,
            such as a balance or payment due.
        invoice_id (str): The API caller-provided external invoice number for
            this order. Appears in both the payer's transaction history and
            the emails that the payer receives.
        custom_id (str): The API caller-provided external ID. Used to
            reconcile API caller-initiated transactions with PayPal
            transactions. Appears in transaction and settlement reports.
        network_transaction_reference (NetworkTransactionReference): Reference
            values used by the card network to identify a transaction.
        seller_protection (SellerProtection): The level of protection offered
            as defined by [PayPal Seller Protection for
            Merchants](https://www.paypal.com/us/webapps/mpp/security/seller-pr
            otection).
        expiration_time (str): The date and time, in [Internet date and time
            format](https://tools.ietf.org/html/rfc3339#section-5.6). Seconds
            are required while fractional seconds are
            optional.<blockquote><strong>Note:</strong> The regular expression
            provides guidance but does not reject all invalid
            dates.</blockquote>
        links (List[LinkDescription]): An array of related [HATEOAS
            links](/docs/api/reference/api-responses/#hateoas-links).
        create_time (str): The date and time, in [Internet date and time
            format](https://tools.ietf.org/html/rfc3339#section-5.6). Seconds
            are required while fractional seconds are
            optional.<blockquote><strong>Note:</strong> The regular expression
            provides guidance but does not reject all invalid
            dates.</blockquote>
        update_time (str): The date and time, in [Internet date and time
            format](https://tools.ietf.org/html/rfc3339#section-5.6). Seconds
            are required while fractional seconds are
            optional.<blockquote><strong>Note:</strong> The regular expression
            provides guidance but does not reject all invalid
            dates.</blockquote>
        processor_response (ProcessorResponse): The processor response
            information for payment requests, such as direct credit card
            transactions.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "status": 'status',
        "status_details": 'status_details',
        "id": 'id',
        "amount": 'amount',
        "invoice_id": 'invoice_id',
        "custom_id": 'custom_id',
        "network_transaction_reference": 'network_transaction_reference',
        "seller_protection": 'seller_protection',
        "expiration_time": 'expiration_time',
        "links": 'links',
        "create_time": 'create_time',
        "update_time": 'update_time',
        "processor_response": 'processor_response'
    }

    _optionals = [
        'status',
        'status_details',
        'id',
        'amount',
        'invoice_id',
        'custom_id',
        'network_transaction_reference',
        'seller_protection',
        'expiration_time',
        'links',
        'create_time',
        'update_time',
        'processor_response',
    ]

    def __init__(self,
                 status=APIHelper.SKIP,
                 status_details=APIHelper.SKIP,
                 id=APIHelper.SKIP,
                 amount=APIHelper.SKIP,
                 invoice_id=APIHelper.SKIP,
                 custom_id=APIHelper.SKIP,
                 network_transaction_reference=APIHelper.SKIP,
                 seller_protection=APIHelper.SKIP,
                 expiration_time=APIHelper.SKIP,
                 links=APIHelper.SKIP,
                 create_time=APIHelper.SKIP,
                 update_time=APIHelper.SKIP,
                 processor_response=APIHelper.SKIP):
        """Constructor for the AuthorizationWithAdditionalData class"""

        # Initialize members of the class
        if status is not APIHelper.SKIP:
            self.status = status 
        if status_details is not APIHelper.SKIP:
            self.status_details = status_details 
        if id is not APIHelper.SKIP:
            self.id = id 
        if amount is not APIHelper.SKIP:
            self.amount = amount 
        if invoice_id is not APIHelper.SKIP:
            self.invoice_id = invoice_id 
        if custom_id is not APIHelper.SKIP:
            self.custom_id = custom_id 
        if network_transaction_reference is not APIHelper.SKIP:
            self.network_transaction_reference = network_transaction_reference 
        if seller_protection is not APIHelper.SKIP:
            self.seller_protection = seller_protection 
        if expiration_time is not APIHelper.SKIP:
            self.expiration_time = expiration_time 
        if links is not APIHelper.SKIP:
            self.links = links 
        if create_time is not APIHelper.SKIP:
            self.create_time = create_time 
        if update_time is not APIHelper.SKIP:
            self.update_time = update_time 
        if processor_response is not APIHelper.SKIP:
            self.processor_response = processor_response 

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """

        if dictionary is None:
            return None

        # Extract variables from the dictionary
        status = dictionary.get("status") if dictionary.get("status") else APIHelper.SKIP
        status_details = AuthorizationStatusDetails.from_dictionary(dictionary.get('status_details')) if 'status_details' in dictionary.keys() else APIHelper.SKIP
        id = dictionary.get("id") if dictionary.get("id") else APIHelper.SKIP
        amount = Money.from_dictionary(dictionary.get('amount')) if 'amount' in dictionary.keys() else APIHelper.SKIP
        invoice_id = dictionary.get("invoice_id") if dictionary.get("invoice_id") else APIHelper.SKIP
        custom_id = dictionary.get("custom_id") if dictionary.get("custom_id") else APIHelper.SKIP
        network_transaction_reference = NetworkTransactionReference.from_dictionary(dictionary.get('network_transaction_reference')) if 'network_transaction_reference' in dictionary.keys() else APIHelper.SKIP
        seller_protection = SellerProtection.from_dictionary(dictionary.get('seller_protection')) if 'seller_protection' in dictionary.keys() else APIHelper.SKIP
        expiration_time = dictionary.get("expiration_time") if dictionary.get("expiration_time") else APIHelper.SKIP
        links = None
        if dictionary.get('links') is not None:
            links = [LinkDescription.from_dictionary(x) for x in dictionary.get('links')]
        else:
            links = APIHelper.SKIP
        create_time = dictionary.get("create_time") if dictionary.get("create_time") else APIHelper.SKIP
        update_time = dictionary.get("update_time") if dictionary.get("update_time") else APIHelper.SKIP
        processor_response = ProcessorResponse.from_dictionary(dictionary.get('processor_response')) if 'processor_response' in dictionary.keys() else APIHelper.SKIP
        # Return an object of this model
        return cls(status,
                   status_details,
                   id,
                   amount,
                   invoice_id,
                   custom_id,
                   network_transaction_reference,
                   seller_protection,
                   expiration_time,
                   links,
                   create_time,
                   update_time,
                   processor_response)



# -*- coding: utf-8 -*-

"""
paypalserversdk

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""
from paypalserversdk.api_helper import APIHelper
from paypalserversdk.models.amount_with_breakdown import AmountWithBreakdown
from paypalserversdk.models.item import Item
from paypalserversdk.models.payee import Payee
from paypalserversdk.models.payment_collection import PaymentCollection
from paypalserversdk.models.payment_instruction import PaymentInstruction
from paypalserversdk.models.shipping_with_tracking_details import ShippingWithTrackingDetails
from paypalserversdk.models.supplementary_data import SupplementaryData


class PurchaseUnit(object):

    """Implementation of the 'Purchase Unit' model.

    The purchase unit details. Used to capture required information for the
    payment contract.

    Attributes:
        reference_id (str): The API caller-provided external ID for the
            purchase unit. Required for multiple purchase units when you must
            update the order through `PATCH`. If you omit this value and the
            order contains only one purchase unit, PayPal sets this value to
            `default`. <blockquote><strong>Note:</strong> If there are
            multiple purchase units, <code>reference_id</code> is required for
            each purchase unit.</blockquote>
        amount (AmountWithBreakdown): The total order amount with an optional
            breakdown that provides details, such as the total item amount,
            total tax amount, shipping, handling, insurance, and discounts, if
            any.<br/>If you specify `amount.breakdown`, the amount equals
            `item_total` plus `tax_total` plus `shipping` plus `handling` plus
            `insurance` minus `shipping_discount` minus discount.<br/>The
            amount must be a positive number. For listed of supported
            currencies and decimal precision, see the PayPal REST APIs <a
            href="/docs/integration/direct/rest/currency-codes/">Currency
            Codes</a>.
        payee (Payee): The merchant who receives the funds and fulfills the
            order. The merchant is also known as the payee.
        payment_instruction (PaymentInstruction): Any additional payment
            instructions to be consider during payment processing. This
            processing instruction is applicable for Capturing an order or
            Authorizing an Order.
        description (str): The purchase description.
        custom_id (str): The API caller-provided external ID. Used to
            reconcile API caller-initiated transactions with PayPal
            transactions. Appears in transaction and settlement reports.
        invoice_id (str): The API caller-provided external invoice ID for this
            order.
        id (str): The PayPal-generated ID for the purchase unit. This ID
            appears in both the payer's transaction history and the emails
            that the payer receives. In addition, this ID is available in
            transaction and settlement reports that merchants and API callers
            can use to reconcile transactions. This ID is only available when
            an order is saved by calling
            <code>v2/checkout/orders/id/save</code>.
        soft_descriptor (str): The payment descriptor on account transactions
            on the customer's credit card statement, that PayPal sends to
            processors. The maximum length of the soft descriptor information
            that you can pass in the API field is 22 characters, in the
            following format:<code>22 - len(PAYPAL * (8)) -
            len(<var>Descriptor in Payment Receiving Preferences of Merchant
            account</var> + 1)</code>The PAYPAL prefix uses 8
            characters.<br/><br/>The soft descriptor supports the following
            ASCII characters:<ul><li>Alphanumeric
            characters</li><li>Dashes</li><li>Asterisks</li><li>Periods
            (.)</li><li>Spaces</li></ul>For Wallet payments marketplace
            integrations:<ul><li>The merchant descriptor in the Payment
            Receiving Preferences must be the marketplace name.</li><li>You
            can't use the remaining space to show the customer service
            number.</li><li>The remaining spaces can be a combination of
            seller name and country.</li></ul><br/>For unbranded payments
            (Direct Card) marketplace integrations, use a combination of the
            seller name and phone number.
        items (List[Item]): An array of items that the customer purchases from
            the merchant.
        shipping (ShippingWithTrackingDetails): The order shipping details.
        supplementary_data (SupplementaryData): Supplementary data about a
            payment. This object passes information that can be used to
            improve risk assessments and processing costs, for example, by
            providing Level 2 and Level 3 payment data.
        payments (PaymentCollection): The collection of payments, or
            transactions, for a purchase unit in an order. For example,
            authorized payments, captured payments, and refunds.
        most_recent_errors (List[object]): The error reason code and
            description that are the reason for the most recent order
            decline.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "reference_id": 'reference_id',
        "amount": 'amount',
        "payee": 'payee',
        "payment_instruction": 'payment_instruction',
        "description": 'description',
        "custom_id": 'custom_id',
        "invoice_id": 'invoice_id',
        "id": 'id',
        "soft_descriptor": 'soft_descriptor',
        "items": 'items',
        "shipping": 'shipping',
        "supplementary_data": 'supplementary_data',
        "payments": 'payments',
        "most_recent_errors": 'most_recent_errors'
    }

    _optionals = [
        'reference_id',
        'amount',
        'payee',
        'payment_instruction',
        'description',
        'custom_id',
        'invoice_id',
        'id',
        'soft_descriptor',
        'items',
        'shipping',
        'supplementary_data',
        'payments',
        'most_recent_errors',
    ]

    def __init__(self,
                 reference_id=APIHelper.SKIP,
                 amount=APIHelper.SKIP,
                 payee=APIHelper.SKIP,
                 payment_instruction=APIHelper.SKIP,
                 description=APIHelper.SKIP,
                 custom_id=APIHelper.SKIP,
                 invoice_id=APIHelper.SKIP,
                 id=APIHelper.SKIP,
                 soft_descriptor=APIHelper.SKIP,
                 items=APIHelper.SKIP,
                 shipping=APIHelper.SKIP,
                 supplementary_data=APIHelper.SKIP,
                 payments=APIHelper.SKIP,
                 most_recent_errors=APIHelper.SKIP):
        """Constructor for the PurchaseUnit class"""

        # Initialize members of the class
        if reference_id is not APIHelper.SKIP:
            self.reference_id = reference_id 
        if amount is not APIHelper.SKIP:
            self.amount = amount 
        if payee is not APIHelper.SKIP:
            self.payee = payee 
        if payment_instruction is not APIHelper.SKIP:
            self.payment_instruction = payment_instruction 
        if description is not APIHelper.SKIP:
            self.description = description 
        if custom_id is not APIHelper.SKIP:
            self.custom_id = custom_id 
        if invoice_id is not APIHelper.SKIP:
            self.invoice_id = invoice_id 
        if id is not APIHelper.SKIP:
            self.id = id 
        if soft_descriptor is not APIHelper.SKIP:
            self.soft_descriptor = soft_descriptor 
        if items is not APIHelper.SKIP:
            self.items = items 
        if shipping is not APIHelper.SKIP:
            self.shipping = shipping 
        if supplementary_data is not APIHelper.SKIP:
            self.supplementary_data = supplementary_data 
        if payments is not APIHelper.SKIP:
            self.payments = payments 
        if most_recent_errors is not APIHelper.SKIP:
            self.most_recent_errors = most_recent_errors 

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """

        if dictionary is None:
            return None

        # Extract variables from the dictionary
        reference_id = dictionary.get("reference_id") if dictionary.get("reference_id") else APIHelper.SKIP
        amount = AmountWithBreakdown.from_dictionary(dictionary.get('amount')) if 'amount' in dictionary.keys() else APIHelper.SKIP
        payee = Payee.from_dictionary(dictionary.get('payee')) if 'payee' in dictionary.keys() else APIHelper.SKIP
        payment_instruction = PaymentInstruction.from_dictionary(dictionary.get('payment_instruction')) if 'payment_instruction' in dictionary.keys() else APIHelper.SKIP
        description = dictionary.get("description") if dictionary.get("description") else APIHelper.SKIP
        custom_id = dictionary.get("custom_id") if dictionary.get("custom_id") else APIHelper.SKIP
        invoice_id = dictionary.get("invoice_id") if dictionary.get("invoice_id") else APIHelper.SKIP
        id = dictionary.get("id") if dictionary.get("id") else APIHelper.SKIP
        soft_descriptor = dictionary.get("soft_descriptor") if dictionary.get("soft_descriptor") else APIHelper.SKIP
        items = None
        if dictionary.get('items') is not None:
            items = [Item.from_dictionary(x) for x in dictionary.get('items')]
        else:
            items = APIHelper.SKIP
        shipping = ShippingWithTrackingDetails.from_dictionary(dictionary.get('shipping')) if 'shipping' in dictionary.keys() else APIHelper.SKIP
        supplementary_data = SupplementaryData.from_dictionary(dictionary.get('supplementary_data')) if 'supplementary_data' in dictionary.keys() else APIHelper.SKIP
        payments = PaymentCollection.from_dictionary(dictionary.get('payments')) if 'payments' in dictionary.keys() else APIHelper.SKIP
        most_recent_errors = dictionary.get("most_recent_errors") if dictionary.get("most_recent_errors") else APIHelper.SKIP
        # Return an object of this model
        return cls(reference_id,
                   amount,
                   payee,
                   payment_instruction,
                   description,
                   custom_id,
                   invoice_id,
                   id,
                   soft_descriptor,
                   items,
                   shipping,
                   supplementary_data,
                   payments,
                   most_recent_errors)



# -*- coding: utf-8 -*-

"""
paypalserversdk

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""
from paypalserversdk.api_helper import APIHelper
from paypalserversdk.models.money import Money


class AmountBreakdown(object):

    """Implementation of the 'Amount Breakdown' model.

    The breakdown of the amount. Breakdown provides details such as total item
    amount, total tax amount, shipping, handling, insurance, and discounts, if
    any.

    Attributes:
        item_total (Money): The currency and amount for a financial
            transaction, such as a balance or payment due.
        shipping (Money): The currency and amount for a financial transaction,
            such as a balance or payment due.
        handling (Money): The currency and amount for a financial transaction,
            such as a balance or payment due.
        tax_total (Money): The currency and amount for a financial
            transaction, such as a balance or payment due.
        insurance (Money): The currency and amount for a financial
            transaction, such as a balance or payment due.
        shipping_discount (Money): The currency and amount for a financial
            transaction, such as a balance or payment due.
        discount (Money): The currency and amount for a financial transaction,
            such as a balance or payment due.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "item_total": 'item_total',
        "shipping": 'shipping',
        "handling": 'handling',
        "tax_total": 'tax_total',
        "insurance": 'insurance',
        "shipping_discount": 'shipping_discount',
        "discount": 'discount'
    }

    _optionals = [
        'item_total',
        'shipping',
        'handling',
        'tax_total',
        'insurance',
        'shipping_discount',
        'discount',
    ]

    def __init__(self,
                 item_total=APIHelper.SKIP,
                 shipping=APIHelper.SKIP,
                 handling=APIHelper.SKIP,
                 tax_total=APIHelper.SKIP,
                 insurance=APIHelper.SKIP,
                 shipping_discount=APIHelper.SKIP,
                 discount=APIHelper.SKIP):
        """Constructor for the AmountBreakdown class"""

        # Initialize members of the class
        if item_total is not APIHelper.SKIP:
            self.item_total = item_total 
        if shipping is not APIHelper.SKIP:
            self.shipping = shipping 
        if handling is not APIHelper.SKIP:
            self.handling = handling 
        if tax_total is not APIHelper.SKIP:
            self.tax_total = tax_total 
        if insurance is not APIHelper.SKIP:
            self.insurance = insurance 
        if shipping_discount is not APIHelper.SKIP:
            self.shipping_discount = shipping_discount 
        if discount is not APIHelper.SKIP:
            self.discount = discount 

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """

        if dictionary is None:
            return None

        # Extract variables from the dictionary
        item_total = Money.from_dictionary(dictionary.get('item_total')) if 'item_total' in dictionary.keys() else APIHelper.SKIP
        shipping = Money.from_dictionary(dictionary.get('shipping')) if 'shipping' in dictionary.keys() else APIHelper.SKIP
        handling = Money.from_dictionary(dictionary.get('handling')) if 'handling' in dictionary.keys() else APIHelper.SKIP
        tax_total = Money.from_dictionary(dictionary.get('tax_total')) if 'tax_total' in dictionary.keys() else APIHelper.SKIP
        insurance = Money.from_dictionary(dictionary.get('insurance')) if 'insurance' in dictionary.keys() else APIHelper.SKIP
        shipping_discount = Money.from_dictionary(dictionary.get('shipping_discount')) if 'shipping_discount' in dictionary.keys() else APIHelper.SKIP
        discount = Money.from_dictionary(dictionary.get('discount')) if 'discount' in dictionary.keys() else APIHelper.SKIP
        # Return an object of this model
        return cls(item_total,
                   shipping,
                   handling,
                   tax_total,
                   insurance,
                   shipping_discount,
                   discount)



# -*- coding: utf-8 -*-

"""
paypalserversdk

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""
from paypalserversdk.api_helper import APIHelper
from paypalserversdk.models.money import Money
from paypalserversdk.models.payee_base import PayeeBase


class CobrandedCard(object):

    """Implementation of the 'Cobranded Card' model.

    Details about the merchant cobranded card used for order purchase.

    Attributes:
        labels (List[str]): Array of labels for the cobranded card.
        payee (PayeeBase): The details for the merchant who receives the funds
            and fulfills the order. The merchant is also known as the payee.
        amount (Money): The currency and amount for a financial transaction,
            such as a balance or payment due.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "labels": 'labels',
        "payee": 'payee',
        "amount": 'amount'
    }

    _optionals = [
        'labels',
        'payee',
        'amount',
    ]

    def __init__(self,
                 labels=APIHelper.SKIP,
                 payee=APIHelper.SKIP,
                 amount=APIHelper.SKIP):
        """Constructor for the CobrandedCard class"""

        # Initialize members of the class
        if labels is not APIHelper.SKIP:
            self.labels = labels 
        if payee is not APIHelper.SKIP:
            self.payee = payee 
        if amount is not APIHelper.SKIP:
            self.amount = amount 

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """

        if dictionary is None:
            return None

        # Extract variables from the dictionary
        labels = dictionary.get("labels") if dictionary.get("labels") else APIHelper.SKIP
        payee = PayeeBase.from_dictionary(dictionary.get('payee')) if 'payee' in dictionary.keys() else APIHelper.SKIP
        amount = Money.from_dictionary(dictionary.get('amount')) if 'amount' in dictionary.keys() else APIHelper.SKIP
        # Return an object of this model
        return cls(labels,
                   payee,
                   amount)



# -*- coding: utf-8 -*-

"""
paypalserversdk

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""
from paypalserversdk.api_helper import APIHelper
from paypalserversdk.models.link_description import LinkDescription
from paypalserversdk.models.pay_pal_wallet_customer import PayPalWalletCustomer


class PayPalWalletVaultResponse(object):

    """Implementation of the 'PayPal Wallet Vault Response' model.

    The details about a saved PayPal Wallet payment source.

    Attributes:
        id (str): The PayPal-generated ID for the saved payment source.
        status (PayPalWalletVaultStatus): The vault status.
        links (List[LinkDescription]): An array of request-related HATEOAS
            links.
        customer (PayPalWalletCustomer): The details about a customer in
            PayPal's system of record.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "id": 'id',
        "status": 'status',
        "links": 'links',
        "customer": 'customer'
    }

    _optionals = [
        'id',
        'status',
        'links',
        'customer',
    ]

    def __init__(self,
                 id=APIHelper.SKIP,
                 status=APIHelper.SKIP,
                 links=APIHelper.SKIP,
                 customer=APIHelper.SKIP):
        """Constructor for the PayPalWalletVaultResponse class"""

        # Initialize members of the class
        if id is not APIHelper.SKIP:
            self.id = id 
        if status is not APIHelper.SKIP:
            self.status = status 
        if links is not APIHelper.SKIP:
            self.links = links 
        if customer is not APIHelper.SKIP:
            self.customer = customer 

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """

        if dictionary is None:
            return None

        # Extract variables from the dictionary
        id = dictionary.get("id") if dictionary.get("id") else APIHelper.SKIP
        status = dictionary.get("status") if dictionary.get("status") else APIHelper.SKIP
        links = None
        if dictionary.get('links') is not None:
            links = [LinkDescription.from_dictionary(x) for x in dictionary.get('links')]
        else:
            links = APIHelper.SKIP
        customer = PayPalWalletCustomer.from_dictionary(dictionary.get('customer')) if 'customer' in dictionary.keys() else APIHelper.SKIP
        # Return an object of this model
        return cls(id,
                   status,
                   links,
                   customer)
